import { Task, initialState } from '@lit/task';
import { CSSResult, LitElement, PropertyValues, ReactiveController, ReactiveControllerHost, SVGTemplateResult, TemplateResult, nothing } from 'lit';

export type CardNetwork = {
	displayName: string;
	network: string;
};
export type CardNetworksContextType = {
	detectedCardNetwork: CardNetwork | null;
	selectableCardNetworks: CardNetwork[];
	isLoading: boolean;
} | null;
export type SdkState = {
	isSuccessful: boolean;
	isProcessing: boolean;
	error: Error | null;
	isLoading: boolean;
	failure: {
		code: string;
		message: string;
		details?: Record<string, unknown>;
	} | null;
};
export type SdkStateContextType = SdkState | null;
declare const PaymentInstrumentType: {
	readonly WORLDPAY_IDEAL: "WORLDPAY_IDEAL";
	readonly AUTOMATED_CLEARING_HOUSE: "AUTOMATED_CLEARING_HOUSE";
	readonly ADYEN_KLARNA: "ADYEN_KLARNA";
	readonly ADYEN_BANCONTACT_CARD: "ADYEN_BANCONTACT_CARD";
	readonly PAY_NL_KAARTDIRECT: "PAY_NL_KAARTDIRECT";
	readonly ADYEN_EPS: "ADYEN_EPS";
	readonly ADYEN_BANCONTACT_PAYCONIQ: "ADYEN_BANCONTACT_PAYCONIQ";
	readonly OMISE_PROMPTPAY: "OMISE_PROMPTPAY";
	readonly OMISE_TRUEMONEY: "OMISE_TRUEMONEY";
	readonly ADYEN_MULTIBANCO: "ADYEN_MULTIBANCO";
	readonly PACYPAY_WECHAT: "PACYPAY_WECHAT";
	readonly PACYPAY_ALIPAY: "PACYPAY_ALIPAY";
	readonly ADYEN_MBWAY: "ADYEN_MBWAY";
	readonly XENDIT_DANA: "XENDIT_DANA";
	readonly XENDIT_SHOPEEPAY: "XENDIT_SHOPEEPAY";
	readonly ADYEN_PAYSHOP: "ADYEN_PAYSHOP";
	readonly ADYEN_PAYTRAIL: "ADYEN_PAYTRAIL";
	readonly CLEARPAY: "CLEARPAY";
	readonly RAPYD_FAST: "RAPYD_FAST";
	readonly RAPYD_PROMPTPAY: "RAPYD_PROMPTPAY";
	readonly RAPYD_GCASH: "RAPYD_GCASH";
	readonly RAPYD_POLI: "RAPYD_POLI";
	readonly RAPYD_GRABPAY: "RAPYD_GRABPAY";
	readonly PRIMER_PAYPAL: "PRIMER_PAYPAL";
	readonly TWOC2P: "TWOC2P";
	readonly NETS: "NETS";
	readonly STRIPE_ACH: "STRIPE_ACH";
	readonly STRIPE_GIROPAY: "STRIPE_GIROPAY";
	readonly MOLLIE_GIROPAY: "MOLLIE_GIROPAY";
	readonly MOLLIE_EPS: "MOLLIE_EPS";
	readonly PAY_NL_EPS: "PAY_NL_EPS";
	readonly PAY_NL_P24: "PAY_NL_P24";
	readonly MOLLIE_P24: "MOLLIE_P24";
	readonly MOLLIE_SOFORT: "MOLLIE_SOFORT";
	readonly COINBASE: "COINBASE";
	readonly OPENNODE: "OPENNODE";
	readonly MOLLIE_GIFT_CARD: "MOLLIE_GIFTCARD";
	readonly XFERS_PAYNOW: "XFERS_PAYNOW";
	readonly CARD: "PAYMENT_CARD";
	readonly APPLE_PAY: "APPLE_PAY";
	readonly GOOGLE_PAY: "GOOGLE_PAY";
	readonly PAYPAL: "PAYPAL_ORDER";
	readonly PAYPAL_VAULTED: "PAYPAL_BILLING_AGREEMENT";
	readonly GO_CARDLESS: "GOCARDLESS";
	readonly PAY_NL_IDEAL: "PAY_NL_IDEAL";
	readonly PAY_NL_SOFORT_BANKING: "PAY_NL_SOFORT_BANKING";
	readonly PAY_NL_BANCONTACT: "PAY_NL_BANCONTACT";
	readonly PAY_NL_PAYPAL: "PAY_NL_PAYPAL";
	readonly PAY_NL_CREDIT_TRANSFER: "PAY_NL_CREDIT_TRANSFER";
	readonly PAY_NL_DIRECT_DEBIT: "PAY_NL_DIRECT_DEBIT";
	readonly PAY_NL_GIROPAY: "PAY_NL_GIROPAY";
	readonly PAY_NL_PAYCONIQ: "PAY_NL_PAYCONIQ";
	readonly PAY_NL_RIVERTY: "PAY_NL_RIVERTY";
	readonly HOOLAH: "HOOLAH";
	readonly ADYEN_BLIK: "ADYEN_BLIK";
	readonly ADYEN_VIPPS: "ADYEN_VIPPS";
	readonly ADYEN_GIROPAY: "ADYEN_GIROPAY";
	readonly ADYEN_SOFORT: "ADYEN_SOFORT";
	readonly ADYEN_IDEAL: "ADYEN_IDEAL";
	readonly ADYEN_TRUSTLY: "ADYEN_TRUSTLY";
	readonly ADYEN_ALIPAY: "ADYEN_ALIPAY";
	readonly ADYEN_TWINT: "ADYEN_TWINT";
	readonly ADYEN_MOBILEPAY: "ADYEN_MOBILEPAY";
	readonly MOLLIE_BANCONTACT: "MOLLIE_BANCONTACT";
	readonly MOLLIE_IDEAL: "MOLLIE_IDEAL";
	readonly BUCKAROO_GIROPAY: "BUCKAROO_GIROPAY";
	readonly BUCKAROO_EPS: "BUCKAROO_EPS";
	readonly BUCKAROO_SOFORT: "BUCKAROO_SOFORT";
	readonly BUCKAROO_BANCONTACT: "BUCKAROO_BANCONTACT";
	readonly BUCKAROO_IDEAL: "BUCKAROO_IDEAL";
	readonly ATOME: "ATOME";
	readonly KLARNA_CUSTOMER_TOKEN: "KLARNA_CUSTOMER_TOKEN";
	readonly DLOCAL_PIX: "DLOCAL_PIX";
	readonly ALMA: "ALMA";
};
export type PaymentInstrumentType = (typeof PaymentInstrumentType)[keyof typeof PaymentInstrumentType];
declare const PaymentMethodType: {
	readonly WORLDPAY_IDEAL: "WORLDPAY_IDEAL";
	readonly STRIPE_ACH: "STRIPE_ACH";
	readonly STRIPE_IDEAL: "STRIPE_IDEAL";
	readonly ADYEN_KLARNA: "ADYEN_KLARNA";
	readonly ADYEN_BANCONTACT_CARD: "ADYEN_BANCONTACT_CARD";
	readonly PAY_NL_KAARTDIRECT: "PAY_NL_KAARTDIRECT";
	readonly ADYEN_EPS: "ADYEN_EPS";
	readonly ADYEN_BANCONTACT_PAYCONIQ: "ADYEN_BANCONTACT_PAYCONIQ";
	readonly OMISE_PROMPTPAY: "OMISE_PROMPTPAY";
	readonly OMISE_TRUEMONEY: "OMISE_TRUEMONEY";
	readonly ADYEN_MULTIBANCO: "ADYEN_MULTIBANCO";
	readonly PACYPAY_WECHAT: "PACYPAY_WECHAT";
	readonly PACYPAY_ALIPAY: "PACYPAY_ALIPAY";
	readonly ADYEN_MBWAY: "ADYEN_MBWAY";
	readonly XENDIT_DANA: "XENDIT_DANA";
	readonly XENDIT_SHOPEEPAY: "XENDIT_SHOPEEPAY";
	readonly ADYEN_PAYSHOP: "ADYEN_PAYSHOP";
	readonly ADYEN_PAYTRAIL: "ADYEN_PAYTRAIL";
	readonly CLEARPAY: "CLEARPAY";
	readonly RAPYD_FAST: "RAPYD_FAST";
	readonly RAPYD_PROMPTPAY: "RAPYD_PROMPTPAY";
	readonly RAPYD_GCASH: "RAPYD_GCASH";
	readonly RAPYD_POLI: "RAPYD_POLI";
	readonly RAPYD_GRABPAY: "RAPYD_GRABPAY";
	readonly PRIMER_PAYPAL: "PRIMER_PAYPAL";
	readonly TWOC2P: "TWOC2P";
	readonly NETS: "NETS";
	readonly STRIPE_GIROPAY: "STRIPE_GIROPAY";
	readonly MOLLIE_GIROPAY: "MOLLIE_GIROPAY";
	readonly MOLLIE_EPS: "MOLLIE_EPS";
	readonly PAY_NL_EPS: "PAY_NL_EPS";
	readonly PAY_NL_P24: "PAY_NL_P24";
	readonly MOLLIE_P24: "MOLLIE_P24";
	readonly MOLLIE_SOFORT: "MOLLIE_SOFORT";
	readonly COINBASE: "COINBASE";
	readonly OPENNODE: "OPENNODE";
	readonly MOLLIE_GIFT_CARD: "MOLLIE_GIFTCARD";
	readonly XFERS_PAYNOW: "XFERS_PAYNOW";
	readonly PAYMENT_CARD: "PAYMENT_CARD";
	readonly APPLE_PAY: "APPLE_PAY";
	readonly GOOGLE_PAY: "GOOGLE_PAY";
	readonly PAYPAL: "PAYPAL";
	readonly GO_CARDLESS: "GOCARDLESS";
	readonly KLARNA: "KLARNA";
	readonly PAY_NL_IDEAL: "PAY_NL_IDEAL";
	readonly PAY_NL_SOFORT_BANKING: "PAY_NL_SOFORT_BANKING";
	readonly PAY_NL_BANCONTACT: "PAY_NL_BANCONTACT";
	readonly PAY_NL_PAYPAL: "PAY_NL_PAYPAL";
	readonly PAY_NL_CREDIT_TRANSFER: "PAY_NL_CREDIT_TRANSFER";
	readonly PAY_NL_DIRECT_DEBIT: "PAY_NL_DIRECT_DEBIT";
	readonly PAY_NL_GIROPAY: "PAY_NL_GIROPAY";
	readonly PAY_NL_PAYCONIQ: "PAY_NL_PAYCONIQ";
	readonly PAY_NL_RIVERTY: "PAY_NL_RIVERTY";
	readonly HOOLAH: "HOOLAH";
	readonly ADYEN_BLIK: "ADYEN_BLIK";
	readonly ADYEN_MOBILEPAY: "ADYEN_MOBILEPAY";
	readonly ADYEN_VIPPS: "ADYEN_VIPPS";
	readonly ADYEN_GIROPAY: "ADYEN_GIROPAY";
	readonly ADYEN_SOFORT: "ADYEN_SOFORT";
	readonly ADYEN_IDEAL: "ADYEN_IDEAL";
	readonly ADYEN_TRUSTLY: "ADYEN_TRUSTLY";
	readonly ADYEN_ALIPAY: "ADYEN_ALIPAY";
	readonly ADYEN_TWINT: "ADYEN_TWINT";
	readonly ADYEN_BANK_TRANSFER: "ADYEN_BANK_TRANSFER";
	readonly MOLLIE_BANCONTACT: "MOLLIE_BANCONTACT";
	readonly MOLLIE_IDEAL: "MOLLIE_IDEAL";
	readonly BUCKAROO_GIROPAY: "BUCKAROO_GIROPAY";
	readonly BUCKAROO_EPS: "BUCKAROO_EPS";
	readonly BUCKAROO_SOFORT: "BUCKAROO_SOFORT";
	readonly BUCKAROO_BANCONTACT: "BUCKAROO_BANCONTACT";
	readonly BUCKAROO_IDEAL: "BUCKAROO_IDEAL";
	readonly ATOME: "ATOME";
	readonly DLOCAL_PIX: "DLOCAL_PIX";
	readonly ALMA: "ALMA";
};
export type PaymentMethodType = (typeof PaymentMethodType)[keyof typeof PaymentMethodType];
export type APIVersionOption = "legacy" | "2.4";
declare enum HeadlessManagerType {
	CARD = "CARD",
	NATIVE = "NATIVE",
	REDIRECT = "REDIRECT",
	KLARNA = "KLARNA",
	ACH = "ACH"
}
declare enum EventTypes {
	CHANGE = "change",
	ERROR = "error",
	FOCUS = "focus",
	BLUR = "blur",
	CLICK = "click",
	CLOSE = "close",
	CONFIRMED_KLARNA_CATEGORY = "CONFIRMED_KLARNA_CATEGORY",
	CONFIRMED_KLARNA_CATEGORY_ERROR = "CONFIRMED_KLARNA_CATEGORY_ERROR",
	KLARNA_SESSION_UPDATE = "KLARNA_SESSION_UPDATE",
	KLARNA_SESSION_REFRESH_ERROR = "KLARNA_SESSION_REFRESH_ERROR"
}
export interface BasePaymentInstrumentData {
	[key: string]: unknown;
}
export interface ClientSessionLineItem {
	amount: number;
	description: string;
	discountAmount?: number;
	itemId: string;
	name?: string;
	productType?: "DIGITAL" | "PHYSICAL" | "SHIPPING_FEE";
	quantity: number;
	taxAmount?: number;
	taxCode?: string;
}
export interface ClientSessionShipping {
	amount: number;
	methodId?: string;
	methodName?: string;
	methodDescription?: string;
}
export interface ClientSessionFeeItem {
	type?: string;
	description?: string;
	amount: number;
}
export interface ClientSessionAddress {
	firstName?: string;
	lastName?: string;
	addressLine1?: string;
	addressLine2?: string;
	city?: string;
	state?: string;
	countryCode?: string;
	postalCode?: string;
}
export interface ClientSession {
	orderId?: string;
	currencyCode?: string;
	lineItems?: ClientSessionLineItem[];
	totalAmount?: number;
	customerId?: string;
	orderDetails?: {
		countryCode?: string;
		shipping?: ClientSessionShipping;
		fees?: ClientSessionFeeItem[];
	};
	customer?: {
		emailAddress?: string;
		mobileNumber?: string;
		firstName?: string;
		lastName?: string;
		billingAddress?: ClientSessionAddress;
		shippingAddress?: ClientSessionAddress;
		taxId?: string;
		nationalDocumentId?: string;
	};
	paymentMethod?: {
		options?: Record<string, unknown>;
		orderedAllowedCardNetworks?: string[];
		vaultOnSuccess?: boolean;
	};
}
export interface BackgroundColor {
	colored: string;
	dark: string;
	light: string;
}
export interface IconUrl {
	colored: string;
	dark: string;
	light: string;
}
export interface InputStyles {
	base?: {
		color?: string;
		fontFamily?: string;
		fontSize?: string;
		fontWeight?: string;
		lineHeight?: string;
		letterSpacing?: string;
		textTransform?: string;
		background?: string;
		borderRadius?: number | string;
		borderColor?: string | number;
		borderWidth?: string | number;
		borderStyle?: string;
		boxShadow?: string;
		height?: number | string;
		paddingHorizontal?: number;
		hover?: Record<string, unknown>;
		focus?: Record<string, unknown>;
		placeholder?: Record<string, unknown>;
		webkitAutofill?: Record<string, unknown>;
		selection?: Record<string, unknown>;
	};
	error?: Record<string, unknown>;
}
export interface InputValidationError {
	field?: string;
	name: string;
	error: string;
	message: string;
}
export interface Validation {
	valid: boolean;
	validationErrors: InputValidationError[];
	error?: string;
}
export interface InputMetadata {
	errorCode: string | null;
	error: string | null;
	valid: boolean;
	active: boolean;
	dirty: boolean;
	touched: boolean;
	submitted: boolean;
}
export interface PaymentMethodConfig {
	id: string;
	type: PaymentMethodType;
	name: string;
	implementationType: "WEB_REDIRECT" | "NATIVE_SDK";
	displayMetadata: {
		button: {
			backgroundColor: BackgroundColor;
			borderColor: {
				dark: string;
				light: string;
			};
			borderWidth: {
				colored: number;
				dark: number;
				light: number;
			};
			cornerRadius: number;
			iconPositionRelativeToText?: "START" | "END";
			iconUrl: IconUrl;
			text?: string;
			textColor?: {
				dark: string;
				light: string;
			};
		};
		overlay: {
			logo: IconUrl;
			backgroundColor: BackgroundColor;
		};
		popup: {
			width: number;
			height: number;
		};
	};
	options: {
		captureVaultedCardCvv?: boolean;
		clientId?: string;
		threeDSecureToken?: string;
		threeDSecureInitUrl?: string;
		threeDSecureProvider?: string;
		threeDSecureEnabled?: boolean;
	};
	forceRedirect?: boolean;
}
export interface PaymentMethodInfo {
	type: PaymentMethodType;
	managerType: HeadlessManagerType;
}
export type CardNetworkType = "american-express" | "diners-club" | "discover" | "elo" | "hiper" | "hipercard" | "interac" | "jcb" | "maestro" | "mastercard" | "mir" | "unionpay" | "private-label" | "visa";
export interface CardNetworkDetails {
	displayName: string;
	network: string;
	allowed: boolean;
}
export interface CardNetworkChangeEvent {
	detectedCardNetworks: {
		items: CardNetworkDetails[];
		preferred?: CardNetworkDetails;
	};
	selectableCardNetworks?: {
		items: CardNetworkDetails[];
		preferred?: CardNetworkDetails;
	};
	source: "REMOTE" | "LOCAL" | "LOCAL_FALLBACK";
}
export interface CardPaymentMethodSubmitValues {
	cardNetwork?: string;
}
export type CardPreferredFlow = "DEDICATED_SCENE" | "EMBEDDED_IN_HOME";
export interface PaymentCardInstrumentData extends BasePaymentInstrumentData {
	last4Digits: string;
	first6Digits: string;
	expirationMonth: string;
	expirationYear: string;
	cardholderName: string;
	network: string;
	isNetworkTokenized: boolean;
	binData?: {
		network: string;
		issuerCountryCode: string;
		issuerName: string;
		issuerCurrencyCode: string;
		regionalRestriction: string;
		accountNumberType: string;
		accountFundingType: string;
		prepaidReloadableIndicator: string;
		productUsageType: string;
		productCode: string;
		productName: string;
	};
}
export interface PayPalInstrumentData extends BasePaymentInstrumentData {
	externalPayerInfo?: {
		externalPayerId?: string;
		firstName?: string;
		lastName?: string;
		email?: string;
	};
	shippingAddress?: {
		firstName?: string;
		lastName?: string;
		addressLine1?: string;
		addressLine2?: string;
		city?: string;
		state?: string;
		countryCode?: string;
		postalCode?: string;
	};
}
export interface KlarnaInstrumentData extends BasePaymentInstrumentData {
	sessionData?: {
		billingAddress?: {
			firstName?: string;
			lastName?: string;
			email?: string;
			phoneNumber?: string;
			addressLine1?: string;
			addressLine2?: string;
			city?: string;
			state?: string;
			countryCode?: string;
			postalCode?: string;
		};
	};
}
export interface ACHInstrumentData extends BasePaymentInstrumentData {
	accountNumberLastFourDigits: string;
	bankName: string;
	accountType?: string;
	routingNumber?: string;
}
export interface IVaultedPaymentMethod<B extends BasePaymentInstrumentData = BasePaymentInstrumentData, I extends PaymentInstrumentType = PaymentInstrumentType, T extends PaymentMethodType = PaymentMethodType> {
	id: string;
	analyticsId: string;
	paymentInstrumentData: B;
	paymentInstrumentType: I;
	paymentMethodType: T;
	threeDSecureAuthentication?: ThreeDSAuthenticationData | null;
	vaultData?: VaultData | null;
	userDescription?: string;
	isVaulted?: boolean;
}
export type PaymentCardVaultedMethod = IVaultedPaymentMethod<PaymentCardInstrumentData, typeof PaymentInstrumentType.CARD, typeof PaymentMethodType.PAYMENT_CARD>;
export type PayPalVaultedMethod = IVaultedPaymentMethod<PayPalInstrumentData, typeof PaymentInstrumentType.PAYPAL_VAULTED, typeof PaymentMethodType.PAYPAL>;
export type KlarnaVaultedMethod = IVaultedPaymentMethod<KlarnaInstrumentData, typeof PaymentInstrumentType.KLARNA_CUSTOMER_TOKEN, typeof PaymentMethodType.KLARNA>;
export type ACHVaultedMethod = IVaultedPaymentMethod<ACHInstrumentData, typeof PaymentInstrumentType.AUTOMATED_CLEARING_HOUSE, typeof PaymentMethodType.STRIPE_ACH>;
export type VaultedPaymentMethod = PaymentCardVaultedMethod | PayPalVaultedMethod | KlarnaVaultedMethod | ACHVaultedMethod | IVaultedPaymentMethod;
export interface CardSecurityCodeInputOptions {
	ariaLabel?: string;
	container: string | Element | HTMLElement;
	id?: string;
	name?: string;
	placeholder?: string;
	placement?: "append" | "prepend";
	properties?: unknown;
	style?: CheckoutStyle;
	cardNetwork?: string;
}
export interface CvvInput {
	frame: HTMLIFrameElement | null;
	readonly metadata: {
		readonly errorCode: string | null;
		readonly error: string | null;
		readonly valid: boolean;
		readonly active: boolean;
		readonly dirty: boolean;
		readonly touched: boolean;
		readonly submitted: boolean;
	};
	focus(): void;
	blur(): void;
	addListener(event: "change" | "blur" | "focus", listener: (...args: unknown[]) => void): (() => void) | undefined;
	addEventListener(event: "change" | "blur" | "focus", listener: (...args: unknown[]) => void): (() => void) | undefined;
	removeListener(event: "change" | "blur" | "focus", listener: (...args: unknown[]) => void): void;
	name: string;
	valueToken: string;
	remove: () => void;
}
export interface Payment {
	id: string;
	orderId: string;
	paymentMethodData?: {
		paymentMethodType: PaymentMethodType;
		reference?: string;
		expiresAt?: string;
		entity?: string;
	};
}
export interface KlarnaPaymentMethodCategory {
	id: string;
	name: string;
	descriptiveAssetUrl: string;
	standardAssetUrl: string;
}
export interface StripeAchCustomerDetails {
	emailAddress: string;
	firstName: string;
	lastName: string;
}
export interface PrimerClientErrorOptions<T = unknown> {
	message: string;
	diagnosticsId?: string;
	severity?: "ERROR" | "DEBUG" | "WARN" | "INFO";
	errorId?: string;
	data?: T;
	isFromDeveloper?: boolean;
}
declare enum ErrorCode {
	INITIALIZATION_ERROR = "INITIALIZATION_ERROR",
	NO_PAYMENT_METHODS = "NO_PAYMENT_METHODS",
	PRIMER_TEARDOWN = "PRIMER_TEARDOWN",
	PRIMER_SERVER_ERROR = "PRIMER_SERVER_ERROR",
	THREE_DS_AUTH_FAILED = "THREE_DS_AUTH_FAILED",
	TOKENIZATION_ERROR = "TOKENIZATION_ERROR",
	DUPLICATE_PAYMENT_METHOD_ERROR = "DUPLICATE_PAYMENT_METHOD_ERROR",
	CARD_NUMBER_ERROR = "CARD_NUMBER_ERROR",
	PAYMENT_METHOD_NOT_SETUP = "PAYMENT_METHOD_NOT_SETUP",
	PAYMENT_METHOD_NOT_PROVIDED = "PAYMENT_METHOD_NOT_PROVIDED",
	PAYMENT_METHOD_NOT_COMPATIBLE = "PAYMENT_METHOD_NOT_COMPATIBLE",
	RESUME_ERROR = "RESUME_ERROR",
	VALIDATION_ERROR = "VALIDATION_ERROR",
	PAYMENT_FAILED = "PAYMENT_FAILED",
	PAYMENT_CREATION_ABORTED = "PAYMENT_CREATION_ABORTED",
	PAYMENT_CREATION_DISABLED = "PAYMENT_CREATION_DISABLED",
	CLIENT_SESSION_UPDATE_ERROR = "CLIENT_SESSION_UPDATE_ERROR",
	INVALID_ARGUMENT = "INVALID_ARGUMENT",
	VAULT_FETCH = "VAULT_FETCH",
	VAULT_DELETE = "VAULT_DELETE",
	HEADLESS_VAULT_MANAGER_VALIDATION = "HEADLESS_VAULT_MANAGER_VALIDATION",
	CARD_FORM_VALIDATION_UNEXPECTED_FIELD = "CARD_FORM_VALIDATION_UNEXPECTED_FIELD",
	MISSING_FIRST_NAME_OR_LAST_NAME = "MISSING_FIRST_NAME_OR_LAST_NAME",
	MISSING_EMAIL_ADDRESS = "MISSING_EMAIL_ADDRESS",
	INVALID_FLOW = "INVALID_FLOW"
}
declare class PrimerClientError<T = unknown> extends Error {
	readonly code: ErrorCode;
	readonly diagnosticsId: string | null;
	readonly data?: T;
	readonly isFromDeveloper: boolean;
	constructor(code: ErrorCode, options: PrimerClientErrorOptions<T>);
	static fromErrorCode(code: ErrorCode, options: PrimerClientErrorOptions): PrimerClientError;
}
export interface IHeadlessHostedInput {
	getOptions(): {
		placeholder?: string;
		ariaLabel?: string;
		style?: CheckoutStyle;
	};
	setOptions(options: {
		placeholder?: string;
		ariaLabel?: string;
		style?: CheckoutStyle;
	}): void;
	render(container: string | Element | null, options: {
		placeholder?: string;
		ariaLabel?: string;
		style?: CheckoutStyle;
	}): Promise<void>;
	addEventListener(event: EventTypes, callback: EventListener$1): void;
	focus(): void;
	blur(): void;
	setDisabled(status: boolean): void;
}
export interface ICardPaymentMethodManager {
	createHostedInputs(): {
		cardNumberInput: IHeadlessHostedInput;
		expiryInput: IHeadlessHostedInput;
		cvvInput: IHeadlessHostedInput;
	};
	setCardholderName(cardholderName: string): void;
	removeHostedInputs(): void;
	submit(values?: CardPaymentMethodSubmitValues): Promise<void>;
	validate(): Promise<Validation>;
	reset(): void;
}
export interface IHeadlessPaymentMethodButton {
	render(containerId: string | Element, options: {
		style?: Record<string, unknown>;
	}): Promise<void>;
	setDisabled(disabled: boolean): Promise<void>;
	clean(): void;
	focus(): void;
	blur(): void;
	addEventListener(event: EventTypes, callback: EventListener$1): void;
}
export interface INativePaymentMethodManager {
	createButton(): IHeadlessPaymentMethodButton;
}
export interface IRedirectPaymentMethodManager {
	start(): Promise<void>;
	addEventListener(event: EventTypes, callback: EventListener$1): void;
}
export interface IKlarnaPaymentMethodManager {
	start(paymentPayload: {
		paymentMethodCategoryId: string;
	}): Promise<{
		outcome: "APPROVED" | "DENIED";
	}>;
	renderCategory(renderCategoryDetails: {
		containerId: string | Element;
		paymentMethodCategoryId: string;
		onHeightChange: (height: number) => void;
	}): Promise<void>;
	addEventListener(event: EventTypes, callback: EventListener$1): void;
	getPaymentMethod(): void;
}
export interface IAchPaymentMethodManager {
	start(paymentDetails: StripeAchCustomerDetails): Promise<Validation | void>;
	setAndValidate(paymentDetails: StripeAchCustomerDetails): Promise<Validation>;
	collectBankAccountDetails(): Promise<void>;
	confirmMandate(): Promise<void>;
	declineMandate(): Promise<void>;
	getPaymentMethod(): void;
}
export interface HeadlessVaultManager {
	fetchVaultedPaymentMethods(): Promise<VaultedPaymentMethod[]>;
	deleteVaultedPaymentMethod(id: string): Promise<void>;
	startPaymentFlow(id: string, data?: {
		cvv?: string;
	}): Promise<void>;
	createCvvInput(options: CardSecurityCodeInputOptions): Promise<CvvInput | null>;
}
export interface IAssetsManager {
	getCardNetworkAsset(cardNetwork: string): Promise<{
		cardUrl: string;
		displayName: string;
	}>;
	getPaymentMethodAsset(type: PaymentMethodType): Promise<{
		backgroundColor: BackgroundColor;
		iconUrl: IconUrl;
		paymentMethodName?: string;
		buttonText?: string;
		displayName?: string;
	} | null>;
}
export interface HeadlessSDKUtilities {
	getCardNetworkAsset(network: string): {
		cardUrl: string;
		displayName: string;
	};
	getUIOrderAmount(): string | null;
	getCDNAssets(paymentMethodType: PaymentMethodType): Promise<{
		assets: {
			icon: string;
		};
		colors: {
			background: string;
			main: string;
		};
		description: string | null;
		is_primer_app: boolean;
		name: string;
		website: string | null;
		goatCdnUrl: string;
	} | undefined>;
	getPaymentMethodConfiguration(paymentMethodType: PaymentMethodType): PaymentMethodConfig | undefined;
}
export interface CardPaymentMethodManagerOptions {
	onCardMetadataChange?: (metadata: {
		type: CardNetworkType | null;
		possibleTypes: string[];
		cvvLength: number;
		cardNumberLength: number;
	}) => void;
	onCardNetworksChange?: (event: CardNetworkChangeEvent) => void;
	onCardNetworksLoading?: () => void;
}
export interface KlarnaPaymentMethodManagerOptions {
	onPaymentMethodCategoriesChange?: (paymentMethodCategories: KlarnaPaymentMethodCategory[]) => void;
	onPaymentMethodAction?: (action: string, data: {
		paymentMethodType: string;
		category: string;
	}) => void;
}
export interface AchPaymentMethodManagerOptions {
	onCollectBankAccountDetailsComplete?: () => void;
}
export type PaymentMethodManagerOptions = CardPaymentMethodManagerOptions | KlarnaPaymentMethodManagerOptions | AchPaymentMethodManagerOptions;
export interface CheckoutStyle {
	fontFaces?: Array<{
		fontFamily?: string;
		src?: string;
		unicodeRange?: string;
		fontVariant?: string;
		fontFeatureSettings?: string;
		fontVariationSettings?: string;
		fontStretch?: string;
		fontWeight?: string;
		fontStyle?: string;
	}>;
	stylesheets?: Array<{
		href: string;
	}>;
	loadingScreen?: {
		color?: string;
	};
	input?: InputStyles;
	inputLabel?: Record<string, unknown>;
	inputErrorText?: Record<string, unknown>;
	formSpacings?: {
		betweenLabelAndInput?: string;
		betweenInputs?: string;
	};
	showMorePaymentMethodsButton?: Record<string, unknown>;
	networkError?: Record<string, unknown>;
	submitButton?: Record<string, unknown>;
	vaultTitle?: Record<string, unknown>;
	savedPaymentMethodButton?: Record<string, unknown>;
	paymentMethodButton?: Record<string, unknown>;
	errorMessage?: Record<string, unknown>;
	smallPrint?: Record<string, unknown>;
	directDebit?: Record<string, unknown>;
	vaultMenu?: Record<string, unknown>;
	backButton?: Record<string, unknown>;
	separator?: Record<string, unknown>;
	processingIndicator?: Record<string, unknown>;
	focusCheckoutOnInit?: boolean;
}
export interface ThreeDSAuthenticationData {
	responseCode: "AUTH_SUCCESS" | "AUTH_FAILED" | "SKIPPED" | "CHALLENGE";
	reasonCode?: string;
	reasonText?: string;
	protocolVersion: string;
	challengeIssued: boolean;
}
export interface VaultData {
	customerId: string;
}
type EventListener$1 = (event?: Event) => void;
export interface PrimerHeadlessCheckout {
	createPaymentMethodManager(type: "PAYMENT_CARD", options?: PaymentMethodManagerOptions): Promise<ICardPaymentMethodManager | null>;
	createPaymentMethodManager(type: "PAYPAL" | "GOOGLE_PAY" | "APPLE_PAY", options?: PaymentMethodManagerOptions): Promise<INativePaymentMethodManager | null>;
	createPaymentMethodManager(type: "STRIPE_ACH", options?: AchPaymentMethodManagerOptions): Promise<IAchPaymentMethodManager | null>;
	createPaymentMethodManager(type: "KLARNA", options?: PaymentMethodManagerOptions): Promise<IKlarnaPaymentMethodManager | null>;
	createPaymentMethodManager(type: PaymentMethodType, options?: PaymentMethodManagerOptions): Promise<IRedirectPaymentMethodManager | null>;
	createVaultManager(): HeadlessVaultManager;
	getSDKUtilities(): HeadlessSDKUtilities;
	configure: (options: Omit<HeadlessUniversalCheckoutOptions, "clientSessionCachingEnabled">) => void;
	getAssetsManager(): IAssetsManager;
	start: () => Promise<void>;
	refreshClientSession(): Promise<boolean>;
}
export interface HeadlessUniversalCheckoutOptions {
	style?: CheckoutStyle;
	paymentHandling?: "AUTO" | "MANUAL";
	locale?: string;
	card?: {
		cardholderName?: {
			required?: boolean;
			visible?: boolean;
			placeholder?: string;
		};
		cardNumber?: {
			placeholder?: string;
		};
		expiryDate?: {
			placeholder?: string;
		};
		cvv?: {
			placeholder?: string;
		};
		preferredFlow?: CardPreferredFlow;
	};
	redirect?: {
		returnUrl?: string;
		forceRedirect?: boolean;
	};
	paypal?: PayPalOptions;
	googlePay?: GooglePayOptions;
	applePay?: ApplePayOptions;
	adyenKlarna?: {
		buttonOptions?: {
			text?: string;
		};
	};
	klarna?: KlarnaOptions;
	directDebit?: {
		customerCountryCode: string;
		companyName: string;
		companyAddress: string;
		customerName?: string;
		customerEmail?: string;
		customerAddressLine1?: string;
		customerAddressLine2?: string;
		customerCity?: string;
		customerPostalCode?: string;
		iban?: string;
		submitButtonLabels?: {
			form?: string;
			mandate: string;
		};
	};
	giftCard?: {
		logoSrc: string;
		background: string;
		logoAlt?: string;
		text?: string;
	};
	stripe?: {
		publishableKey?: string;
		mandateData?: {
			fullMandateText?: string;
			merchantName?: string;
		};
	} & Record<string, unknown>;
	onAvailablePaymentMethodsLoad: (paymentMethods: PaymentMethodInfo[]) => void;
	clientSessionCachingEnabled?: boolean;
	apiVersion?: APIVersionOption;
	onCheckoutComplete?: (data: {
		payment: Payment | null;
	}) => void;
	onCheckoutFail?: (error: PrimerClientError, data: {
		payment?: Payment;
	}, handler?: {
		showErrorMessage: (errorMessage?: string) => void;
	}) => void;
	onBeforePaymentCreate?: (data: {
		paymentMethodType?: PaymentMethodType;
	}, handler: {
		continuePaymentCreation: () => void;
		abortPaymentCreation: () => void;
	}) => void;
	onPaymentCreationStart?: () => void;
	onPaymentMethodAction?: (data: "PAYMENT_METHOD_SELECTED" | "PAYMENT_METHOD_UNSELECTED", handler: {
		paymentMethodType: PaymentMethodType | null;
	}) => void;
	onClientSessionUpdate?: (clientSession: ClientSession) => void;
	onBeforeClientSessionUpdate?: () => void;
	onTokenizeShouldStart?: (data: {
		paymentMethodType?: PaymentMethodType;
	}) => boolean | Promise<boolean>;
	onTokenizeDidNotStart?: (reason: string) => void;
	onTokenizeStart?: () => void;
	onTokenizeSuccess?: (data: PaymentMethodToken, handler: {
		handleSuccess(): unknown;
		handleFailure(errorMessage?: string): unknown;
		continueWithNewClientToken(clientToken: string): unknown;
	}) => void | Promise<void>;
	onTokenizeError?: (error: PrimerClientError) => void;
	onResumeSuccess?: (data: {
		resumeToken: string;
		paymentId?: string;
	}, handler: {
		handleSuccess(): unknown;
		handleFailure(errorMessage?: string): unknown;
		continueWithNewClientToken(clientToken: string): unknown;
	}) => void;
	onResumePending?: (paymentMethodData: {
		paymentMethodType: PaymentMethodType;
		reference?: string;
		expiresAt?: string;
		entity?: string;
	}) => void;
	onResumeError?: (error: PrimerClientError) => void;
}
export interface PaymentMethodToken {
	token: string;
	analyticsId: string;
	tokenType: "SINGLE_USE" | "MULTI_USE";
	paymentInstrumentData: BasePaymentInstrumentData;
	paymentInstrumentType: PaymentInstrumentType;
	threeDSecureAuthentication: ThreeDSAuthenticationData | null;
	vaultData: VaultData | null;
}
export interface ApplePayOptions {
	container?: string | Element;
	buttonType?: "plain" | "buy" | "set-up" | "donate" | "check-out" | "book" | "subscribe";
	buttonStyle?: "white" | "white-outline" | "black";
	captureBillingAddress?: boolean;
	billingOptions?: {
		requiredBillingContactFields?: Array<"emailAddress" | "name" | "phoneNumber" | "postalAddress" | "phoneticName">;
	};
	shippingOptions?: {
		requiredShippingContactFields?: Array<"emailAddress" | "name" | "phoneNumber" | "postalAddress" | "phoneticName">;
		requireShippingMethod?: boolean;
	};
}
export interface GooglePayOptions {
	container?: string | Element;
	buttonType?: "long" | "short" | "book" | "buy" | "checkout" | "donate" | "order" | "pay" | "plain" | "subscribe";
	buttonColor?: "default" | "black" | "white";
	buttonSizeMode?: "fill" | "static";
	onClick?: () => void;
	captureBillingAddress?: boolean;
	shippingAddressParameters?: {
		phoneNumberRequired?: boolean;
	};
	emailRequired?: boolean;
	requireShippingMethod?: boolean;
	shadowRoot?: boolean;
}
export interface PayPalOptions {
	container?: string | Element;
	buttonColor?: "gold" | "blue" | "silver" | "white" | "black";
	buttonShape?: "pill" | "rect";
	buttonSize?: "small" | "medium" | "large" | "responsive";
	buttonHeight?: number;
	buttonLabel?: "checkout" | "credit" | "pay" | "buynow" | "paypal" | "installment";
	buttonTagline?: boolean;
	paymentFlow?: "DEFAULT" | "PREFER_VAULT";
	onClick?: () => void;
}
export interface KlarnaOptions {
	paymentFlow?: "DEFAULT" | "PREFER_VAULT";
	recurringPaymentDescription?: string;
	allowedPaymentCategories?: Array<"pay_now" | "pay_later" | "pay_over_time">;
	buttonOptions?: {
		text?: string;
	};
}
/**
 * PrimerCheckoutOptions defines the configuration options for the Primer checkout.
 * This is an explicit definition of the options rather than a mapped type to make
 * the type more predictable and easier to maintain.
 */
export interface PrimerCheckoutOptions {
	clientToken?: string;
	locale?: string;
	apiVersion?: APIVersionOption;
	card?: {
		cardholderName?: {
			required?: boolean;
		};
	};
	applePay?: Omit<ApplePayOptions, "container"> & {
		captureBillingAddress?: boolean;
		billingOptions?: {
			requiredBillingContactFields?: Array<"emailAddress" | "name" | "phoneNumber" | "postalAddress" | "phoneticName">;
		};
		shippingOptions?: {
			requiredShippingContactFields?: Array<"emailAddress" | "name" | "phoneNumber" | "postalAddress" | "phoneticName">;
			requireShippingMethod?: boolean;
		};
	};
	googlePay?: Omit<GooglePayOptions, "container">;
	paypal?: Omit<PayPalOptions, "container">;
	klarna?: KlarnaOptions;
	threeDsOptions?: {
		enabled?: boolean;
		preferred?: boolean;
	};
	vault?: {
		enabled: boolean;
		showEmptyState?: boolean;
	};
	stripe?: {
		mandateData: {
			fullMandateText?: string;
			merchantName?: string;
		};
		publishableKey?: string;
	} & Record<string, unknown>;
	submitButton?: {
		amountVisible?: boolean;
	};
	sdkCore?: boolean;
	disabledPayments?: boolean;
}
export type InitializedManager = {
	type: typeof PaymentMethodType.STRIPE_ACH;
	manager: IAchPaymentMethodManager;
} | {
	type: typeof PaymentMethodType.PAYMENT_CARD;
	manager: ICardPaymentMethodManager;
} | {
	type: typeof PaymentMethodType.KLARNA;
	manager: IKlarnaPaymentMethodManager;
} | {
	type: RedirectPaymentMethodTypes;
	manager: IRedirectPaymentMethodManager;
} | {
	type: typeof PaymentMethodType.PAYPAL | typeof PaymentMethodType.GOOGLE_PAY | typeof PaymentMethodType.APPLE_PAY;
	manager: INativePaymentMethodManager;
};
export type ManagerByType<T extends PaymentMethodType> = Extract<InitializedManager, {
	type: T;
}>;
export interface InitializedManagersMap extends Map<PaymentMethodType, InitializedManager> {
	get<T extends PaymentMethodType>(key: T): ManagerByType<T> | undefined;
}
export type RedirectPaymentMethodTypes = Exclude<PaymentMethodType, typeof PaymentMethodType.STRIPE_ACH | typeof PaymentMethodType.PAYMENT_CARD | typeof PaymentMethodType.KLARNA | typeof PaymentMethodType.PAYPAL | typeof PaymentMethodType.GOOGLE_PAY | typeof PaymentMethodType.APPLE_PAY>;
export type DynamicPaymentMethodTypes = typeof PaymentMethodType.STRIPE_ACH;
export type NativePaymentMethodTypes = typeof PaymentMethodType.PAYPAL | typeof PaymentMethodType.GOOGLE_PAY | typeof PaymentMethodType.APPLE_PAY;
export type RedirectPaymentMethod = {
	type: RedirectPaymentMethodTypes;
	managerType: HeadlessManagerType.REDIRECT;
};
export type InitializedPaymentMethod = {
	type: typeof PaymentMethodType.STRIPE_ACH;
	managerType: HeadlessManagerType.ACH;
} | {
	type: typeof PaymentMethodType.PAYMENT_CARD;
	managerType: HeadlessManagerType.CARD;
} | {
	type: typeof PaymentMethodType.KLARNA;
	managerType: HeadlessManagerType.KLARNA;
} | {
	type: typeof PaymentMethodType.PAYPAL;
	managerType: HeadlessManagerType.NATIVE;
} | {
	type: typeof PaymentMethodType.GOOGLE_PAY;
	managerType: HeadlessManagerType.NATIVE;
} | {
	type: typeof PaymentMethodType.APPLE_PAY;
	managerType: HeadlessManagerType.NATIVE;
} | RedirectPaymentMethod;
export type PaymentMethodByType<T extends PaymentMethodType> = Extract<InitializedPaymentMethod, {
	type: T;
}>;
export interface InitializedPaymentMethodMap extends Map<PaymentMethodType, InitializedPaymentMethod> {
	get<T extends PaymentMethodType>(key: T): PaymentMethodByType<T> | undefined;
}
export interface AssetsConfig {
	backgroundColor: string;
	name: string;
	iconUrl: string;
}
export declare class InitializedPayments {
	private readonly _methods;
	constructor(map: InitializedPaymentMethodMap);
	get<T extends RedirectPaymentMethodTypes>(type: T): RedirectPaymentMethod | undefined;
	get<T extends (typeof PaymentMethodType)[keyof typeof PaymentMethodType]>(type: T): PaymentMethodByType<T> | undefined;
	toArray(): InitializedPaymentMethod[];
	size(): number;
}
export interface PaymentData {
	paymentMethodType: string;
}
export interface PrepareHandler {
	continuePaymentCreation: () => void;
	abortPaymentCreation: () => void;
}
export interface PaymentCompleteData {
	payment: Payment | null;
	status: "success" | "pending" | "error";
	error?: PrimerClientError;
}
/**
 * PrimerJS is a wrapper class that provides a stable API for interfacing with the Primer SDK
 * while hiding direct access to the legacy headless instance.
 */
export declare class PrimerJS {
	private headlessInstance;
	private paymentMethods;
	onPaymentStart?: () => void;
	onPaymentPrepare?: (data: PaymentData, handler: PrepareHandler) => void;
	onPaymentComplete?: (data: PaymentCompleteData) => void;
	constructor(headlessInstance: PrimerHeadlessCheckout);
	/**
	 * Set the initialized payment methods
	 * @internal - This is only used internally by the SDK
	 */
	setPaymentMethods(methods: InitializedPayments): void;
	/**
	 * Refetches a new client session from merchant backend.
	 */
	refreshSession(): Promise<void>;
	/**
	 * Returns the cached list of payment methods.
	 */
	getPaymentMethods(): PaymentMethodInfo[];
	/**
	 * Internal method to handle the onPaymentStart callback
	 * @internal - This is only used internally by the SDK
	 */
	handlePaymentStart(): void;
	/**
	 * Internal method to handle the onBeforePaymentCreate callback and transform it to onPaymentPrepare
	 * @internal - This is only used internally by the SDK
	 */
	handleBeforePaymentCreate(data: PaymentData, originalHandler: {
		continuePaymentCreation: () => void;
		abortPaymentCreation: () => void;
	}): void;
	/**
	 * Internal method to handle payment completion (success)
	 * @internal - This is only used internally by the SDK
	 */
	handlePaymentComplete(payment: Payment | null): void;
	/**
	 * Internal method to handle payment failure
	 * @internal - This is only used internally by the SDK
	 */
	handlePaymentFailure(error: PrimerClientError, payment?: Payment): void;
}
export interface CardSubmitSuccessPayload {
	result: unknown;
}
export interface CardSubmitErrorsPayload {
	errors: unknown;
}
export interface CardSubmitPayload {
	source?: string;
}
export interface PrimeAchErrorPayload {
	error: Error;
}
export interface PrimerEvents {
	"primer:state-change": CustomEvent<SdkStateContextType>;
	"primer:methods-update": CustomEvent<InitializedPayments>;
	"primer:ready": CustomEvent<PrimerJS>;
	"primer:card-network-change": CustomEvent<CardNetworksContextType>;
	"primer:card-submit": CustomEvent<CardSubmitPayload>;
	"primer:card-success": CustomEvent<CardSubmitSuccessPayload>;
	"primer:card-error": CustomEvent<CardSubmitErrorsPayload>;
	"primer-ach-error": CustomEvent<PrimeAchErrorPayload>;
	"primer-ach-bank-details-collected": CustomEvent;
	"primer-ach-mandate-confirmed": CustomEvent;
	"primer-ach-mandate-declined": CustomEvent;
}
declare class PrimerEventsController implements ReactiveController {
	host: ReactiveControllerHost & LitElement;
	constructor(host: ReactiveControllerHost & LitElement);
	hostConnected(): void;
	/**
	 * Dispatch a custom event using the unified naming pattern.
	 * Ensures that every event bubbles and crosses shadow DOM boundaries.
	 *
	 * @param type - The event name as defined in PrimerEvents.
	 * @param detail - The payload for the event.
	 */
	dispatchEvent<K extends keyof PrimerEvents>(type: K, detail: PrimerEvents[K]["detail"]): void;
	dispatchSdkState(sdkState: SdkStateContextType): void;
	dispatchPaymentMethods(paymentMethods: InitializedPayments): void;
	dispatchCheckoutInitialized(checkoutInstance: PrimerJS): void;
	dispatchCardNetworkChange(network: CardNetworksContextType): void;
	dispatchCardSubmit(source?: string): void;
	dispatchFormSubmitSuccess(result: unknown): void;
	dispatchFormSubmitErrors(errors: unknown): void;
}
export type HeadlessUnitilsContextType = HeadlessSDKUtilities | null;
export type KlarnaCategoriesContextType = {
	categories: KlarnaPaymentMethodCategory[];
	isLoading: boolean;
};
export type ReducerCallbacks<State, _Action extends {
	type: string;
}> = {
	[K in keyof State]?: State[K] extends (...args: unknown[]) => unknown ? State[K] : never;
};
export type TypedReducer<State, Action extends {
	type: string;
}, Callbacks> = (state: State, action: Action, callbacks: Callbacks) => State;
declare abstract class ReactiveStateController<Host extends ReactiveControllerHost, State, Action extends {
	type: string;
}, Callbacks = ReducerCallbacks<State, Action> | null> implements ReactiveController {
	protected host: Host;
	protected stateHandler: (state: State) => void;
	private _dispatcher;
	constructor(host: Host, initialState: State, reducer: TypedReducer<State, Action, Callbacks>, initialCallbacks: Callbacks, stateHandler?: (state: State) => void);
	get currentState(): Readonly<State>;
	protected dispatch(action: Action): void;
	protected setCallbacks(callbacks: Partial<Callbacks>): void;
	hostConnected(): void;
	hostDisconnected(): void;
}
declare class CompositeStateController<Host extends ReactiveControllerHost> implements ReactiveController {
	protected host: Host;
	private _controllers;
	constructor(host: Host);
	addController<State, Action extends {
		type: string;
	}, Callbacks = ReducerCallbacks<State, Action> | null>(controller: ReactiveStateController<Host, State, Action, Callbacks>): void;
	hostConnected(): void;
	hostDisconnected(): void;
}
/**
 * Options for initializing the Vault Manager
 */
export interface VaultManagerInitOptions {
	vaultEnabled?: boolean;
	captureVaultedCardCvv?: boolean;
	showEmptyState?: boolean;
}
/**
 * Core state interface for vault manager
 * Contains properties related to vault functionality that don't change frequently
 */
export interface VaultManagerState {
	enabled: boolean;
	isLoading: boolean;
	isUpdating: boolean;
	vaultedPaymentMethods: VaultedPaymentMethod[];
	cvvRecapture: boolean;
	showEmptyState: boolean;
	createCvvInput: ((options: CardSecurityCodeInputOptions) => Promise<CvvInput | null>) | null;
	deleteVaultedPaymentMethod: (paymentMethodId: string) => Promise<void>;
	startVaultedPaymentFlow: (options?: {
		cvv?: string;
	}) => Promise<void>;
}
/**
 * CVV-specific state interface
 * Contains properties specifically related to CVV input functionality
 */
export interface VaultManagerItemState {
	formIsDirty: boolean;
	cvvInput: CvvInput | null;
	setCvvInput: (metadata: CvvInput | null) => void;
	selectedVaultedPaymentMethod: VaultedPaymentMethod | null;
	setSelectedVaultedPaymentMethod: (paymentMethod: VaultedPaymentMethod | null) => void;
}
declare class VaultManagerController extends CompositeStateController<PrimerCheckoutType> {
	private coreController;
	private itemController;
	private _vaultManager;
	private _options;
	constructor(host: PrimerCheckoutType);
	/**
	 * Initialize the vault manager with additional options
	 * @param vaultManager - The HeadlessVaultManager instance
	 * @param options - Additional initialization options
	 */
	initializeVaultManager(vaultManager: HeadlessVaultManager, options?: VaultManagerInitOptions): void;
	get vaultManager(): HeadlessVaultManager | null;
	set vaultManager(vaultManager: HeadlessVaultManager | null);
	get options(): VaultManagerInitOptions | null;
	set options(options: VaultManagerInitOptions | null);
	get vaultManagerState(): Readonly<VaultManagerState>;
	get vaultItemState(): Readonly<VaultManagerItemState>;
	/**
	 * Lifecycle method called when the host disconnects
	 */
	hostDisconnected(): void;
	/**
	 * Fetch vaulted payment methods from the server
	 */
	fetchVaultedPaymentMethods(initialLoad?: boolean): Promise<VaultedPaymentMethod[]>;
	createCvvInput: (options: CardSecurityCodeInputOptions) => Promise<CvvInput | null>;
	/**
	 * Delete a vaulted payment method by ID
	 */
	deleteVaultedPaymentMethod: (paymentMethodId: string) => Promise<void>;
	/**
	 * Set the CVV metadata - updates CVV state only
	 * Moved to the separate CVV context
	 */
	setCvvInput: (metadata: CvvInput | null) => void;
	/**
	 * Start the vaulted payment flow
	 * Verifies form state validity before processing
	 */
	startVaultedPaymentFlow: () => Promise<void>;
	/**
	 * Set the selected vaulted payment method - updates form state only
	 */
	setSelectedVaultedPaymentMethod: (paymentMethod: VaultedPaymentMethod | null) => void;
}
/**
 * Context for core vault manager functionality
 * Contains properties that don't change frequently and relate to vault functionality
 */
export type VaultManagerContextType = VaultManagerState | null;
/**
 * Context for vault manager CVV-specific state
 * Contains properties specifically related to CVV input functionality
 * Further separated to minimize re-renders related to frequently changing CVV input state
 */
export type VaultItemContextType = VaultManagerItemState | null;
declare class SDKContextController implements ReactiveController {
	host: PrimerCheckoutType;
	private sdkStateProvider;
	private paymentMethodsProvider;
	private paymentManagerProvider;
	private cardNetworksContext;
	private vaultManagerProvider;
	private vaultManagerCvvProvider;
	private clientOptionsContext;
	private headlessUtilsProvider;
	private klarnaCategoriesProvider;
	private computedStylesProvider;
	constructor(host: PrimerCheckoutType);
	hostConnected(): void;
	/**
	 * Updates the SDK state context.
	 * @param value The new SDK state.
	 */
	setSdkState(value: SdkStateContextType): void;
	/**
	 * Updates the payment methods context.
	 * @param value The new payment methods data.
	 */
	setPaymentMethods(value: InitializedPayments): void;
	/**
	 * Updates the payment manager context.
	 * @param value The new payment manager mapping.
	 */
	setPaymentManagers(value: InitializedManagersMap): void;
	setCardNetworks(value: CardNetworksContextType): void;
	setVaultManager(value: VaultManagerContextType): void;
	setKlarnaCategories(value: KlarnaCategoriesContextType): void;
	setClientOptions(value: PrimerCheckoutOptions | null): void;
	setHeadlessUtils(value: HeadlessUnitilsContextType): void;
	setComputedStyles(value: CSSStyleDeclaration): void;
	setVaultManagerCvv(value: VaultItemContextType): void;
}
export type SdkStateAction = {
	type: "START_PROCESSING";
} | {
	type: "START_LOADING";
} | {
	type: "COMPLETE_PROCESSING";
} | {
	type: "STOP_PROCESSING";
} | {
	type: "SET_ERROR";
	payload: Error;
} | {
	type: "SET_FAILURE";
	payload: {
		code: string;
		message: string;
		details?: Record<string, unknown>;
	};
} | {
	type: "COMPLETE_LOADING";
} | {
	type: "RESET";
} | {
	type: "RESET_ERROR";
};
declare class SdkStateController extends ReactiveStateController<PrimerCheckoutType, SdkState, SdkStateAction, null> {
	constructor(host: PrimerCheckoutType);
	startLoading(): void;
	startProcessing(): void;
	stopProcessing(): void;
	completeProcessing(): void;
	completeLoading(): void;
	setError(error: Error): void;
	setFailure(code: string, message: string, details?: Record<string, unknown>): void;
	reset(): void;
	resetError(): void;
	forceCompleteLoading(): void;
}
/**
 * PrimerCheckoutType defines the interface for the primer-checkout component implementation.
 * This includes both the properties and controllers needed for internal functionality.
 */
export interface PrimerCheckoutType extends ReactiveControllerHost, LitElement {
	requestUpdate: ReactiveControllerHost["requestUpdate"];
	customStyles: string;
	clientToken: string;
	options: PrimerCheckoutOptions;
	sdkContextController: SDKContextController;
	sdkStateController: SdkStateController;
	primerEventsController: PrimerEventsController;
	vaultManagerController: VaultManagerController;
	cardNetworkController: CardNetworkController;
}
declare class CardNetworkController implements ReactiveController {
	private host;
	constructor(host: PrimerCheckoutType);
	hostConnected(): void;
	/**
	 * Sets the card networks to loading state
	 */
	setCardNetworksLoading(): void;
	/**
	 * Updates card networks state and dispatches events
	 *
	 * @param cardNetworks - The new card networks context
	 */
	private updateCardNetworksState;
	/**
	 * Processes a card network change event
	 *
	 * @param event - The card network change event
	 */
	processCardNetworkChangeEvent(event: CardNetworkChangeEvent): void;
}
declare class StyleProcessingController implements ReactiveController {
	host: ReactiveControllerHost & LitElement;
	private static cssVarCache;
	constructor(host: ReactiveControllerHost & LitElement);
	/**
	 * Processes the customStyles JSON string.
	 * Expected JSON contains only CSS variable properties in camelCase.
	 * @param jsonString The JSON string representing custom styles.
	 */
	processCustomStyles(jsonString: string): void;
	/**
	 * Validates a CSS property name to ensure it follows expected patterns.
	 * @param property The CSS property name to validate.
	 * @returns boolean True if the property name is considered valid.
	 */
	private isValidCssProperty;
	/**
	 * Validates a CSS value to ensure it only contains safe, expected characters.
	 * Allowed characters include alphanumerics, whitespace, and common CSS punctuation.
	 * This helps prevent CSS injection attacks.
	 *
	 * @param value The CSS value to validate.
	 * @returns boolean True if the value is considered valid.
	 */
	private isValidCssValue;
	/**
	 * Gets the CSS variable name for a camelCase property key.
	 * Uses caching for performance.
	 *
	 * @param key The camelCase property key
	 * @returns The CSS variable name (kebab-case with -- prefix)
	 */
	private getCssVarName;
	/**
	 * Transforms a styles object into CSS variables and applies them to the host element.
	 * Each key (in camelCase) is converted into a kebab-case CSS variable prefixed with '--'.
	 * Only valid CSS properties and values are applied.
	 *
	 * @param styles An object with style keys and corresponding CSS values.
	 */
	private applyStyles;
	/**
	 * Removes a specific CSS variable from the host element
	 * @param key The camelCase property key to remove
	 */
	removeStyle(key: string): void;
	/**
	 * Removes all custom styles from the host element
	 */
	clearAllStyles(): void;
	/**
	 * Optional cleanup when the host is disconnected
	 */
	hostDisconnected(): void;
}
declare const sourceLocale = `en`;
declare const targetLocales = [
	`ar`,
	`bg`,
	`ca`,
	`cs`,
	`da`,
	`de`,
	`el`,
	`en-GB`,
	`es`,
	`es-AR`,
	`es-MX`,
	`et-EE`,
	`fi-FI`,
	`fr`,
	`he`,
	`hr`,
	`hu`,
	`id`,
	`it`,
	`ja`,
	`ko`,
	`lt`,
	`lt-LT`,
	`lv`,
	`lv-LV`,
	`ms`,
	`nb`,
	`nl`,
	`nl_NL`,
	`pl`,
	`pt`,
	`pt-BR`,
	`ro`,
	`ru`,
	`sk`,
	`sl`,
	`sr-RS`,
	`sv`,
	`th`,
	`tr`,
	`uk-UA`,
	`vi`,
	`zf`,
	`zh-CN`,
	`zh-HK`,
	`zh-TW`,
] as const;
export type LocaleCode = typeof sourceLocale | (typeof targetLocales)[number];
declare global {
	interface HTMLElementTagNameMap {
		"primer-checkout": PrimerCheckoutComponent;
	}
	type PublicPrimerEvents = Omit<PrimerEvents, "primer-ach-error" | "primer-ach-bank-details-collected" | "primer-ach-mandate-confirmed" | "primer-ach-mandate-declined">;
	interface DocumentEventMap extends PublicPrimerEvents {
	}
	interface HTMLElementEventMap extends PublicPrimerEvents {
	}
}
declare class AchPaymentEventsController implements ReactiveController {
	host: PrimerCheckoutComponent;
	constructor(host: PrimerCheckoutComponent);
	private _error;
	private _mandateConfirmed;
	private _mandateDeclined;
	hostConnected(): void;
	hostDisconnected(): void;
}
/**
 * PrimerCheckoutComponent implements the main checkout experience.
 * This component includes a CSS-only loader that displays before the JavaScript
 * is fully loaded, ensuring users see a loading indicator immediately.
 *
 * The loader can be disabled by:
 * 1. Adding the 'loader-disabled' attribute to the component
 * 2. Setting the CSS custom property --primer-loader-disabled: 1
 */
export declare class PrimerCheckoutComponent extends LitElement implements PrimerCheckoutType {
	set jsInitialized(value: boolean);
	get jsInitialized(): boolean;
	static styles: CSSResult[];
	customStyles: string;
	clientToken: string;
	options: PrimerCheckoutOptions;
	disableLoader: boolean;
	/**
	 * Whether the component has completed initialization and loading
	 * This is used to control the CSS-only loader visibility
	 * @private
	 */
	private _jsInitialized;
	defaultSlot: HTMLSlotElement;
	private previousLoadingState;
	private hasAssignedContent;
	private _loadingTimeoutId;
	locale?: LocaleCode;
	private onSlotChange;
	sdkContextController: SDKContextController;
	sdkStateController: SdkStateController;
	primerEventsController: PrimerEventsController;
	styleProcessingController: StyleProcessingController;
	vaultManagerController: VaultManagerController;
	cardNetworkController: CardNetworkController;
	achPaymentEventsController: AchPaymentEventsController;
	constructor();
	attributeChangedCallback(attrName: string, oldVal: string, newVal: string): void;
	disconnectedCallback(): void;
	willUpdate(changedProperties: PropertyValues): void;
	updated(): void;
	/**
	 * Check if the loading state has changed and update the CSS loader visibility accordingly.
	 * This method is called after each update cycle to detect when loading is complete.
	 */
	private checkLoadingStateChange;
	render(): TemplateResult;
	addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: HTMLElementEventMap[K]) => void, options?: boolean | AddEventListenerOptions): void;
	addEventListener<K extends keyof ShadowRootEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: ShadowRootEventMap[K]) => void, options?: boolean | AddEventListenerOptions): void;
	addEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: DocumentEventMap[K]) => void, options?: boolean | AddEventListenerOptions): void;
	addEventListener<K extends keyof PrimerEvents>(type: K, listener: (this: PrimerCheckoutComponent, ev: PrimerEvents[K]) => void, options?: boolean | AddEventListenerOptions): void;
	removeEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: HTMLElementEventMap[K]) => void, options?: boolean | EventListenerOptions): void;
	removeEventListener<K extends keyof ShadowRootEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: ShadowRootEventMap[K]) => void, options?: boolean | EventListenerOptions): void;
	removeEventListener<K extends keyof DocumentEventMap>(type: K, listener: (this: PrimerCheckoutComponent, ev: DocumentEventMap[K]) => void, options?: boolean | EventListenerOptions): void;
	removeEventListener<K extends keyof PrimerEvents>(type: K, listener: (this: PrimerCheckoutComponent, ev: PrimerEvents[K]) => void, options?: boolean | EventListenerOptions): void;
}
/**
 * Injects the CSS loader styles into the page
 * These styles display a loading indicator before JavaScript initializes
 *
 * Unlike theme styles, loader styles should take precedence over merchant styles
 * to ensure the loading indicator is visible. We append them to the end of the head.
 */
export declare function injectLoaderStyles(): void;
/**
 * Injects all required theme CSS variables into the page
 * This should be called before components are rendered to ensure
 * they have access to all design tokens
 *
 * Theme styles are prepended to the document head to allow merchant styles
 * to override our default variables.
 */
export declare function injectThemeStyles(): void;
/**
 * Utility function to inject only the light theme CSS variables
 * @returns {void}
 */
export declare function injectLightTheme(): void;
/**
 * Utility function to inject only the dark theme CSS variables
 * @returns {void}
 */
export declare function injectDarkTheme(): void;
/**
 * Size options for the spinner component
 */
export type SpinnerSize = "small" | "medium" | "large";
/**
 * Spinner component with configurable size and color
 * Adapted to work both standalone and within input components
 */
declare class SpinnerComponent extends LitElement {
	/**
	 * Color of the spinner
	 * Defaults to the design system loader color
	 */
	color: string;
	/**
	 * Size of the spinner
	 * Available values: 'small', 'medium', 'large' or a custom number as string
	 */
	size: SpinnerSize;
	/**
	 * Whether to use compact mode (minimal margins)
	 * Useful when embedding in inputs
	 */
	compact: boolean;
	static styles: import("lit").CSSResult[];
	/**
	 * Get the actual size value in pixels
	 */
	private getSize;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-spinner": SpinnerComponent;
	}
}
/**
 * A wrapper component for input elements that handles focus styling and interactions.
 * Provides an improved user experience by making the entire wrapper clickable to focus the inner input.
 *
 * Features:
 * - Automatically focuses primer-input elements when wrapper is clicked
 * - Dispatches wrapper-click events for iframe-based hosted inputs
 * - Sets proper cursor styling to indicate text input functionality
 */
declare class InputWrapperComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	focusWithin: boolean;
	hasError: boolean;
	private inputSlot;
	/**
	 * Event handler for click events on the input slot wrapper.
	 * Does one of the following:
	 * 1. If a primer-input is found inside, focus it directly
	 * 2. Otherwise, dispatch a wrapper-click event for hosted inputs to handle
	 */
	private handleWrapperClick;
	/**
	 * Finds the first primer-input element inside the input slot
	 * @returns The primer-input element or null if not found
	 */
	private findSlottedPrimerInput;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-wrapper": InputWrapperComponent;
	}
}
/**
 * Input label component for form elements
 *
 * @element primer-input-label
 * @slot - Default slot for label text content
 */
declare class InputLabelComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * ID of the form control this label is associated with
	 */
	for: string;
	/**
	 * Whether the label should appear disabled
	 */
	disabled: boolean;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-label": InputLabelComponent;
	}
}
/**
 * Simplified selection state for buttons
 */
export type ButtonSelectionState = "default" | "checked";
declare class ButtonComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	variant: "primary" | "secondary" | "tertiary";
	disabled: boolean;
	/**
	 * Loading state of the button
	 * When true, the button will display a spinner and be disabled
	 */
	loading: boolean;
	buttonType: "button" | "submit" | "reset";
	/**
	 * Selection state of the button
	 * - default: Not checked
	 * - checked: Button is checked
	 */
	selectionState: ButtonSelectionState;
	/**
	 * Indicates if this button is selectable/checkable
	 */
	selectable: boolean;
	/**
	 * Indicates if wraps the slot in a flex container
	 */
	flex: boolean;
	/**
	 * Event handler for button click
	 * If selectable, it will toggle between checked and default states
	 */
	private handleClick;
	/**
	 * Renders the checkmark icon when checked
	 */
	private renderCheckmark;
	/**
	 * Renders the spinner when in loading state
	 */
	private renderSpinner;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-button": ButtonComponent;
	}
}
/**
 * Input error component for displaying form validation messages
 *
 * @element primer-input-error
 * @slot - Default slot for error message content
 */
declare class InputErrorComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * ID of the form control this error message is associated with
	 */
	for: string;
	/**
	 * Whether the error is currently active/visible
	 */
	active: boolean;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-error": InputErrorComponent;
	}
}
export type IconName = keyof typeof icons;
declare const icons: Record<string, SVGTemplateResult>;
declare class PrimerIconComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	color: string;
	size: "lg" | "md" | "sm";
	/** The name of the icon to draw - available names can be found under library.ts file */
	name?: IconName;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-icon": PrimerIconComponent;
	}
}
declare class PrimerCheckoutStateComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	type: "complete" | "failure";
	description?: string;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-checkout-state": PrimerCheckoutStateComponent;
	}
}
/**
 * Input types supported by this component
 */
export type InputType = "text" | "password" | "email" | "number" | "tel" | "url" | "search" | "date" | "time" | "datetime-local" | "month" | "week" | "color";
/**
 * Custom events dispatched by this component
 */
export type InputEventMap = {
	input: CustomEvent<string>;
	change: CustomEvent<string>;
	focus: FocusEvent;
	blur: FocusEvent;
	invalid: Event;
};
/**
 * A fully type-safe input component that wraps the native HTML input element
 * while providing additional functionality and styling.
 *
 * @element primer-input
 *
 * @fires input - Fired when the input value changes
 * @fires change - Fired when the input value is committed
 * @fires focus - Fired when the input receives focus
 * @fires blur - Fired when the input loses focus
 * @fires invalid - Fired when the input fails validation
 *
 * @csspart input - The native input element
 */
declare class InputComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private inputElement;
	value: string;
	placeholder: string;
	disabled: boolean;
	name: string;
	type: InputType;
	required: boolean;
	readonly: boolean;
	pattern: string;
	minlength?: number;
	maxlength?: number;
	min: string;
	max: string;
	step: string;
	autocomplete: string;
	private _id;
	get id(): string;
	set id(value: string);
	private hasFocus;
	private hasError;
	/**
	 * Handles input events and dispatches a custom event with the current value
	 */
	private handleInput;
	/**
	 * Handles change events and dispatches a custom event with the committed value
	 */
	private handleChange;
	/**
	 * Handles focus events and updates internal state
	 */
	private handleFocus;
	/**
	 * Handles blur events and updates internal state
	 */
	private handleBlur;
	/**
	 * Handles invalid events and updates internal state
	 */
	private handleInvalid;
	/**
	 * Focus the input element
	 * @param options Optional focus options
	 */
	focus(options?: FocusOptions): void;
	/**
	 * Remove focus from the input element
	 */
	blur(): void;
	/**
	 * Select all text in the input element
	 */
	select(): void;
	/**
	 * Set the selection range of the input element
	 */
	setSelectionRange(start: number, end: number, direction?: "forward" | "backward" | "none"): void;
	/**
	 * Get the validity state of the input element
	 */
	get validity(): ValidityState;
	/**
	 * Get the validation message of the input element
	 */
	get validationMessage(): string;
	/**
	 * Check if the input element is valid
	 */
	checkValidity(): boolean;
	/**
	 * Report the validity of the input element
	 */
	reportValidity(): boolean;
	render(): import("lit-html").TemplateResult<1>;
	/**
	 * Type safe event dispatcher - allows consumers to use proper types
	 * when listening to events from this component
	 */
	addEventListener<K extends keyof InputEventMap>(type: K, listener: (ev: InputEventMap[K]) => void, options?: boolean | AddEventListenerOptions): void;
	/**
	 * Type safe event dispatcher removal
	 */
	removeEventListener<K extends keyof InputEventMap>(type: K, listener: (ev: InputEventMap[K]) => void, options?: boolean | EventListenerOptions): void;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input": InputComponent;
	}
}
/**
 * Event detail interface for expanded-changed event
 */
export interface ExpandedChangedDetail {
	expanded: boolean;
}
/**
 * Button variant types
 */
export type ButtonVariant = "primary" | "secondary" | "tertiary";
/**
 * A collapsable component that smoothly expands and collapses content.
 * Uses CSS Grid for smooth animation and incorporates the primary button.
 */
declare class CollapsableComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * The header text for the collapsable
	 */
	header: string;
	/**
	 * Whether the collapsable is expanded by default
	 */
	expanded: boolean;
	/**
	 * Text for expand button (for accessibility)
	 */
	expandText: string;
	/**
	 * Text for collapse button (for accessibility)
	 */
	collapseText: string;
	/**
	 * ARIA label for the collapsable header
	 */
	ariaLabel: string;
	/**
	 * The button variant to use
	 */
	buttonVariant: ButtonVariant;
	/**
	 * Internal state to track expanded state
	 */
	private isExpanded;
	/**
	 * Hook into the component lifecycle to set the initial expanded state
	 */
	connectedCallback(): void;
	/**
	 * Dispatch the expanded-changed event
	 */
	private dispatchExpandedChangedEvent;
	/**
	 * Toggle the expanded state
	 */
	private toggleExpanded;
	/**
	 * Expand the collapsable programmatically
	 */
	expand(): void;
	/**
	 * Collapse the collapsable programmatically
	 */
	collapse(): void;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-collapsable": CollapsableComponent;
	}
}
/**
 * A reusable atomic error message component that displays error information
 * with appropriate styling and accessibility attributes.
 *
 * This component is fully accessible and designed to work with screen readers.
 * It includes animations for visibility transitions.
 *
 * @element primer-error-message
 *
 * @attr {string} message - The error message text to display
 * @attr {boolean} visible - Whether the error message is visible
 * @attr {string} role - Accessibility role (defaults to "alert")
 *
 * @csspart error-message - The main error message container
 * @csspart error-icon - The error icon container
 * @csspart error-content - The error text content
 */
declare class ErrorMessageComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	constructor();
	/**
	 * The error message text to display
	 */
	message: string;
	/**
	 * Whether the error message is visible
	 */
	visible: boolean;
	/**
	 * Accessibility role for the error message
	 * Defaults to "alert" for proper screen reader announcements
	 */
	private _role;
	get role(): string;
	set role(value: string);
	/**
	 * Internal state to track animation state
	 * This helps manage proper animations with DOM presence/absence
	 */
	private showMessage;
	protected updated(changedProperties: Map<PropertyKey, unknown>): void;
	/**
	 * Handle visibility changes with proper animation timing
	 */
	private handleVisibilityChange;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-error-message": ErrorMessageComponent;
	}
}
declare class PortalComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private _id;
	get id(): string;
	getContainer(): HTMLDivElement;
	/**
	 * Proxies the events sent from the portalled content and
	 * re-dispatches them.
	 *
	 * TODO: find a better way to scale to new events instead
	 * of hardcoding them one by one here.
	 */
	private _setupEventListeners;
	disconnectedCallback(): void;
	private _handleSlotChange;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-portal": PortalComponent;
	}
}
declare class DialogComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private _handleCloseClick;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-dialog": DialogComponent;
	}
}
/**
 * This component renders Klarna payment method in a card-like (accordion) container with
 * payment categories options to choose from.
 *
 * [ Pay with Klarna    v ] --> accordion header
 *
 * [ Pay Now ] [ Buy now, pay later ] --> payment categories options from Klarna
 * [ Continue with Klarna ] --> opens a Klarna popup
 */
declare class PrimerKlarnaComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	paymentManagers: InitializedManagersMap;
	sdkState: SdkStateContextType;
	headlessUtils: HeadlessUnitilsContextType;
	klarnaCategories: KlarnaCategoriesContextType | null;
	disabled: boolean;
	private selectedCategory;
	private isExpanded;
	private headerAriaLabel;
	private klarnaContainer;
	private _paymentMethodManagerTask;
	toggleExpand: () => void;
	startKlarnaPayment(): Promise<void>;
	renderSelectedCategory(): Promise<void>;
	selectCategory(category: string): void;
	updated(changedProperties: Map<string, unknown>): void;
	renderCategorySelection(): import("lit-html").TemplateResult<1>;
	renderExpandedContent(): import("lit-html").TemplateResult<1>;
	render(): typeof nothing | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-klarna": PrimerKlarnaComponent;
	}
}
export type PaymentMethodsContextType = InitializedPayments | null;
declare class PaymentMethodComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	type: PaymentMethodType | undefined;
	disabled: boolean;
	paymentMethods: PaymentMethodsContextType;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-payment-method": PaymentMethodComponent;
	}
}
export type ClientOptionsContextType = PrimerCheckoutOptions | null;
export type AchField = "firstName" | "lastName" | "emailAddress";
export interface AchFormState {
	value: string;
	error: string;
	pristine: boolean;
	touched: boolean;
	dirty: boolean;
	valid: boolean;
}
export type AchFormStateMap = Record<AchField, AchFormState>;
export type ValidationFunction = (data: StripeAchCustomerDetails) => Promise<Validation>;
declare class AchPaymentFormControler implements ReactiveController {
	host: AchPaymentComponent;
	validate: ValidationFunction;
	formState: AchFormStateMap;
	get hasError(): {
		firstName: boolean;
		lastName: boolean;
		emailAddress: boolean;
	};
	get formData(): StripeAchCustomerDetails;
	constructor(host: AchPaymentComponent, validate: ValidationFunction);
	setFieldValue(field: AchField, value: string): Promise<void>;
	setValidation(validation: Validation, submit?: boolean): void;
	setFieldTouched(field: AchField): void;
	resetForm(): void;
	private isValidFieldName;
	hostConnected(): void;
	hostDisconnected(): void;
}
declare class AchPaymentComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	protected readonly formController: AchPaymentFormControler;
	paymentMethod: InitializedPaymentMethod | undefined;
	paymentManagers: InitializedManagersMap;
	sdkState: SdkStateContextType | undefined;
	clientOptions: ClientOptionsContextType | undefined;
	screen: "form" | "mandate";
	private isSubmitting;
	private _paymentMethodManagerTask;
	private _handleInput;
	private _handleBlur;
	private _handleError;
	private _handleSubmitButtonClick;
	private _handleCollectBankAccountDetails;
	private _handleConfirmMandate;
	private _handleDeclineMandate;
	private renderForm;
	private renderMandate;
	render(): TemplateResult | typeof nothing | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-ach-payment": AchPaymentComponent;
	}
}
declare class DynamicPaymentComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	paymentMethod: InitializedPaymentMethod | undefined;
	paymentManagers: InitializedManagersMap;
	sdkState: SdkStateContextType;
	headlessUtils: HeadlessUnitilsContextType;
	open: boolean;
	private _paymentMethodManagerTask;
	private _getAssetsTask;
	/**
	 * Based on packages/primer-sdk-web/src/payment-methods/Button.tsx
	 * Should be replaced once we align on a better solution across all platforms.
	 * TODO: get label from payment config
	 */
	private _legacyGetButtonLabel;
	private _setupTasks;
	start(): void;
	renderDialog(): typeof nothing | import("lit-html").TemplateResult<1>;
	render(): symbol | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-dynamic-payment": DynamicPaymentComponent;
	}
}
declare class RedirectPaymentComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	paymentMethod: InitializedPaymentMethod | undefined;
	disabled: boolean;
	paymentManagers: InitializedManagersMap;
	sdkState: SdkStateContextType;
	headlessUtils: HeadlessUnitilsContextType;
	private _paymentMethodManagerTask;
	/**
	 * Based on packages/primer-sdk-web/src/payment-methods/Button.tsx
	 * Should be replaced once we align on a better solution across all platforms.
	 */
	private _legacyGetButtonLabel;
	private _getAssetsTask;
	private _setupTasks;
	startRedirectPayment(): void;
	render(): symbol | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-redirect-payment": RedirectPaymentComponent;
	}
}
/**
 * Events emitted by the vault manager components
 */
export interface VaultManagerEvents {
	deletePaymentMethod: CustomEvent<string>;
	cancelDelete: CustomEvent<void>;
	confirmDelete: CustomEvent<void>;
	toggleEditMode: CustomEvent<boolean>;
	closeError: CustomEvent<void>;
	vaultPaymentError: CustomEvent<{
		error: unknown;
	}>;
}
/**
 * Declare the event map for strict typing of events
 */
export interface VaultManagerEventMap {
	"delete-payment-method": VaultManagerEvents["deletePaymentMethod"];
	"cancel-delete": VaultManagerEvents["cancelDelete"];
	"confirm-delete": VaultManagerEvents["confirmDelete"];
	"toggle-edit-mode": VaultManagerEvents["toggleEditMode"];
	"close-error": VaultManagerEvents["closeError"];
	"primer-vault-payment-error": VaultManagerEvents["vaultPaymentError"];
}
/**
 * VaultManagerComponent - displays and manages saved payment methods
 */
declare class VaultManagerComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	constructor();
	addEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	removeEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	vaultManagerContext: VaultManagerContextType;
	vaultItemContext: VaultItemContextType;
	headlessUtils: HeadlessUnitilsContextType;
	/**
	 * Whether we're in edit mode
	 */
	private isEditMode;
	/**
	 * Payment method being deleted
	 */
	private deletePaymentMethodId;
	/**
	 * Whether a delete operation is in progress
	 */
	private isDeleting;
	/**
	 * Error message if something goes wrong
	 */
	private errorMessage;
	/**
	 * Animation duration override
	 */
	animationDuration: number;
	/**
	 * Asset config for the payment method being deleted
	 */
	private deleteAssetConfig;
	/**
	 * Get base animation configuration with current settings
	 */
	private getAnimationConfig;
	/**
	 * Toggle edit mode handler
	 */
	private handleToggleEditMode;
	/**
	 * Handle delete click from payment method item
	 */
	private handleDeletePaymentMethod;
	/**
	 * Cancel delete operation
	 */
	private handleCancelDelete;
	/**
	 * Confirm and process payment method deletion
	 */
	private handleConfirmDelete;
	/**
	 * Handle payment error events
	 */
	private handlePaymentError;
	/**
	 * Handle closing error message
	 */
	private handleCloseError;
	/**
	 * Get payment method display name for the given ID
	 */
	private getPaymentMethodName;
	/**
	 * Render loading overlay with spinner when isUpdating is true
	 */
	private renderLoadingOverlay;
	/**
	 * Render delete confirmation content
	 */
	private renderDeleteConfirmation;
	/**
	 * Render a payment method item with appropriate animations
	 */
	private renderPaymentMethodItem;
	/**
	 * Render the payment method list with submit button
	 */
	private renderPaymentMethodList;
	/**
	 * Main render method
	 */
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
/**
 * VaultPaymentMethodItemComponent - displays a single payment method
 * Uses the VaultManagerController for display formatting
 * Now supports selection via the simplified button checked state
 * Enhanced with smooth transitions between edit and payment modes
 * Always renders the primer-button for consistent UI and improved accessibility
 */
declare class VaultPaymentMethodItemComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Strongly typed event declarations
	 */
	addEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	removeEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	/**
	 * Consume the vault manager context
	 */
	vaultManagerContext: VaultManagerContextType;
	vaultItemContext: VaultItemContextType;
	headlessUtils: HeadlessUnitilsContextType;
	/**
	 * The payment method to display
	 */
	paymentMethod: VaultedPaymentMethod | null;
	/**
	 * Whether the component is in edit mode
	 */
	isEditMode: boolean;
	private _getAssetsTask;
	/**
	 * Check if this payment method is currently selected in the context
	 */
	private isSelected;
	/**
	 * Handle when the button is clicked
	 * This is used to select the payment method and deselect others
	 */
	private handleClick;
	/**
	 * Dispatch delete event
	 */
	private handleDeleteClick;
	/**
	 * Render method
	 */
	render(): symbol | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-payment-method-item": VaultPaymentMethodItemComponent;
	}
}
/**
 * VaultManagerHeaderComponent - displays the header for the vault manager
 */
declare class VaultManagerHeaderComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Strongly typed event declarations
	 */
	addEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	removeEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	/**
	 * Whether we're in edit mode
	 */
	isEditMode: boolean;
	/**
	 * Whether we have payment methods to edit
	 */
	hasPaymentMethods: boolean;
	/**
	 * Toggle edit mode
	 */
	private toggleEditMode;
	/**
	 * Render method
	 */
	protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-manager-header": VaultManagerHeaderComponent;
	}
}
/**
 * VaultDeleteConfirmationComponent - displays confirmation UI for deleting a payment method
 */
declare class VaultDeleteConfirmationComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Strongly typed event declarations
	 */
	addEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	removeEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	/**
	 * Whether a delete operation is in progress
	 */
	isDeleting: boolean;
	/**
	 * The ID of the payment method being deleted
	 */
	paymentMethodId: string;
	/**
	 * Payment method name to display in confirmation
	 */
	paymentMethodName: string;
	/**
	 * Consume the vault manager context to access payment method info
	 */
	vaultManager: VaultManagerContextType;
	/**
	 * Handle confirm click
	 */
	private handleConfirmClick;
	/**
	 * Handle cancel click
	 */
	private handleCancelClick;
	/**
	 * Render method
	 */
	protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-delete-confirmation": VaultDeleteConfirmationComponent;
	}
}
/**
 * VaultEmptyStateComponent - displays when no payment methods are available
 */
declare class VaultEmptyStateComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Render method
	 */
	protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-empty-state": VaultEmptyStateComponent;
	}
}
/**
 * VaultErrorMessageComponent - displays error messages with improved visuals
 */
declare class VaultErrorMessageComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Strongly typed event declarations
	 */
	addEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	removeEventListener: <K extends keyof VaultManagerEventMap>(type: K, listener: (ev: VaultManagerEventMap[K]) => void, options?: boolean | AddEventListenerOptions) => void;
	/**
	 * The error message to display
	 */
	errorMessage: string;
	/**
	 * Handle dismiss click
	 */
	private handleDismiss;
	/**
	 * Render method
	 */
	protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-error-message": VaultErrorMessageComponent;
	}
}
/**
 * A submit button component for vault payment flows.
 * Provides a consistent submit button with translation support.
 * Integrates with the vault manager context to handle payment submission.
 */
declare class VaultPaymentSubmitComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private readonly _userAssignedProps;
	private _internalButtonText;
	/**
	 * The button text to display.
	 * Falls back to localized default if not explicitly set.
	 */
	get buttonText(): string;
	set buttonText(value: string);
	headlessInstance: HeadlessUnitilsContextType;
	sdkState: SdkStateContextType;
	vaultItemContext: VaultItemContextType;
	vaultManager: VaultManagerContextType;
	clientOptions: PrimerCheckoutOptions | null;
	/**
	 * The button variant to use.
	 * @default "primary"
	 */
	variant: string;
	/**
	 * Whether the button is disabled.
	 * This property allows external disabling of the button
	 * regardless of the context state.
	 * @default false
	 */
	disabled: boolean;
	/**
	 * Handle button click event.
	 * Prevents default form submission and triggers the vault payment flow.
	 */
	private handleClick;
	/**
	 * Computed property to determine if the button should be disabled
	 */
	private get isButtonDisabled();
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-payment-submit": VaultPaymentSubmitComponent;
	}
}
/**
 * CVV Input component for vault payment methods
 * Renders a secure iframe for CVV input when required by the selected payment method
 * Uses dedicated CVV context to minimize re-renders
 */
declare class VaultCvvInputComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Form context for checking form dirty state
	 */
	vaultManagerFormContext: VaultManagerContextType;
	/**
	 * CVV-specific context for dedicated CVV handling
	 * Separated to minimize re-renders on frequent CVV input changes
	 */
	vaultManagerCvvContext: VaultItemContextType;
	computedStyles: CSSStyleDeclaration | null;
	paymentMethod: PaymentCardVaultedMethod | null;
	private cvvError;
	private cvvInputIsDirty;
	private cvvInputIsBlurred;
	private cvvInput;
	private isFocused;
	/**
	 * Unique ID for the CVV input container
	 */
	private readonly cvvContainerId;
	private _setupCVVIframe;
	constructor();
	disconnectedCallback(): void;
	/**
	 * Update CVV metadata in the context when input changes
	 */
	onCvvInputChange(): void;
	onBlur(): void;
	onFocus(): void;
	/**
	 * Main render method
	 */
	protected render(): symbol | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-cvv-input": VaultCvvInputComponent;
	}
}
export interface CardPaymentMethodDisplay {
	type: "card";
	cardholderName: string;
	last4: string;
	expiresDate: string;
	network: string;
	description: string;
}
export interface OtherPaymentMethodDisplay {
	type: "other";
	fullName?: string;
	paymentMethodType?: "ACH" | "PayPal" | "Klarna";
	email?: string;
	last4?: string;
	bankName?: string;
	accountType?: string;
	description: string;
}
export type AssetConfig = ({
	icon: string;
} & CardPaymentMethodDisplay & {
	shouldShowCVV: boolean;
}) | ({
	icon: string;
} & OtherPaymentMethodDisplay & {
	shouldShowCVV: boolean;
});
/**
 * PaymentMethodContentComponent - renders payment method information with icon and details
 * This component encapsulates the display logic and styles for payment method content
 * so it can be reused across different containers without style conflicts
 */
export declare class PaymentMethodContentComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * The asset configuration containing icon and display data
	 */
	assetConfig: AssetConfig | null;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-payment-method-content": PaymentMethodContentComponent;
	}
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-vault-manager": VaultManagerComponent;
	}
}
/**
 * CardFormComponent serves as a container for card input components.
 * It handles form submission, validation, and provides context to child components.
 */
declare class CardFormComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	hideLabels: boolean;
	disabled: boolean;
	updated(changedProperties: Map<string, unknown>): void;
	/**
	 * Tracks whether custom content has been provided via slot
	 */
	private hasAssignedContent;
	private selectedCardNetwork;
	/**
	 * Payment managers injected from context
	 */
	paymentManagers: InitializedManagersMap;
	/**
	 * Context provider for card form data
	 */
	private readonly cardFormProvider;
	/**
	 * Events controller for dispatching form events
	 */
	private readonly eventsController;
	/**
	 * Task to set up the card form with hosted inputs
	 */
	private readonly setupCardFormTask;
	connectedCallback(): void;
	disconnectedCallback(): void;
	/**
	 * Handles click events from slotted content.
	 * Supports both native <button> and custom <primer-button> elements.
	 */
	private handleSlotButtonClick;
	/**
	 * Handles direct submit events from child components
	 * This is a backup method to catch all possible submission events
	 */
	private handleDirectSubmit;
	/**
	 * Determines if a button is a submit button based on its attributes
	 */
	private isSubmitButton;
	/**
	 * Handles slot change events to detect custom content
	 */
	private onSlotChange;
	/**
	 * Handles the card form submission.
	 * Validates the form and dispatches either a submit success or errors event.
	 */
	private submitCardPayment;
	/**
	 * Event handler for form submission
	 * Handles both native form submissions and custom events
	 */
	private handleFormSubmit;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
export interface CardFormContext {
	cardNumberInput: IHeadlessHostedInput;
	cardHolderNameInput?: IHeadlessHostedInput;
	expiryInput: IHeadlessHostedInput;
	cvvInput: IHeadlessHostedInput;
	setCardholderName: (val: string) => void;
	setCardNetwork: (val: string) => void;
	validate: () => Promise<Validation>;
	submit: (values?: CardPaymentMethodSubmitValues) => Promise<void>;
	errors?: Validation["validationErrors"];
	hideLabels?: boolean;
	disabled?: boolean;
}
/**
 * A shared type that ensures the host of a HostedInputController contains
 * the required properties for proper hosted input handling.
 */
export interface HostedInputHost extends ReactiveControllerHost, LitElement {
	cardFormContext: CardFormContext | null;
	computedStyles: CSSStyleDeclaration | null;
	/** A string for the input placeholder. */
	placeholder: string;
	/** An accessible label for the input. */
	ariaLabel: string;
	/** The label for the input. */
	label: string;
	requestUpdate: ReactiveControllerHost["requestUpdate"];
}
/**
 * Available input types for hosted inputs.
 */
export type HostedInputType = "cardNumber" | "cvv" | "expire" | "cardholderName";
/**
 * Configuration for the hosted input controller.
 */
export interface HostedInputConfig {
	/** Differentiates the input type. */
	type: HostedInputType;
	/** Selector for the container element where the input should be rendered. */
	containerSelector: string;
	/**
	 * Optional callback for handling input events (e.g. for CardFormName).
	 */
	onInput?: (value: string) => void;
}
/**
 * Possible input source types that can be returned by getHostedInput
 */
export type InputSource = IHeadlessHostedInput | "cardholderName" | undefined;
declare class HostedInputController<T extends HostedInputHost> implements ReactiveController {
	private _isFocused;
	private _meta;
	private _hostedInput;
	private _standardInput;
	private readonly host;
	private readonly config;
	/**
	 * Task to set up the hosted input.
	 */
	readonly setupTask: Task<[
		InputSource
	], boolean | typeof initialState>;
	constructor(host: T, config: HostedInputConfig);
	/**
	 * Focuses the input, whether it's a hosted input or standard input
	 */
	focusInput(): void;
	/**
	 * Returns the hosted input from the card form context based on the type.
	 * For 'cardholderName', no hosted input is provided so we return a fallback indicator.
	 */
	private getHostedInput;
	/**
	 * Sets up the hosted input.
	 * If a hosted input is provided, it renders it into the target container.
	 * Otherwise (e.g. for cardholderName), it creates a standard input element.
	 */
	private setupHostedInput;
	/**
	 * Gets the target container element from the host's render root
	 */
	private getTargetContainer;
	/**
	 * Sets up a standard input element for non-hosted input types
	 */
	private setupStandardInput;
	/**
	 * Sets up event listeners for standard input elements
	 */
	private setupInputEventListeners;
	/**
	 * Sets up a hosted iframe input for iframe-based input types
	 */
	private setupHostedIframeInput;
	/** Exposes the current focus state. */
	get isFocused(): boolean;
	/** Exposes the current metadata state. */
	get meta(): InputMetadata;
	hostConnected(): void;
	hostDisconnected(): void;
}
/**
 * Translation configuration object
 */
export type TranslationConfig = {
	id: string;
	defaultMessage: string;
};
/**
 * Configuration for abstract input component
 */
export interface InputComponentConfig {
	/** The component's hosted input type */
	inputType: HostedInputType;
	/** ID selector for the container where the input will be rendered */
	containerSelector: string;
	/** Error name to match in the card form context */
	errorName: string;
	/** Translation keys for default values */
	translations: {
		label: TranslationConfig | string;
		placeholder?: TranslationConfig | string;
		ariaLabel?: TranslationConfig | string;
	};
	/** Optional input handler for non-hosted inputs */
	onInput?: (value: string) => void;
}
declare abstract class AbstractCardInputComponent extends LitElement implements HostedInputHost {
	cardFormContext: CardFormContext | null;
	computedStyles: CSSStyleDeclaration | null;
	/** Tracks which properties were explicitly set by the user */
	protected readonly _userAssignedProps: Set<string>;
	/** Internal storage for property values */
	protected _internalLabel: string;
	protected _internalPlaceholder: string;
	protected _internalAriaLabel: string;
	/** Configuration for this input component */
	protected abstract readonly config: InputComponentConfig;
	/** Hosted input controller */
	protected readonly hostedInputController: HostedInputController<HostedInputHost>;
	/**
	 * Gets a translated or static string value from the translation config
	 */
	private getTranslatedValue;
	/**
	 * The input label text.
	 * Falls back to localized default if not explicitly set.
	 */
	get label(): string;
	set label(value: string);
	/**
	 * The input placeholder text.
	 * Falls back to localized default if not explicitly set.
	 * When explicitly set to empty string, no placeholder will be displayed.
	 */
	get placeholder(): string;
	set placeholder(value: string);
	/**
	 * The input aria-label attribute.
	 * Falls back to localized default if not explicitly set.
	 */
	get ariaLabel(): string;
	set ariaLabel(value: string);
	constructor();
	/**
	 * Initialize the controller after the component has been constructed
	 * and the config is available
	 */
	protected childUpdated(): void;
	/**
	 * Handler for wrapper-click event from InputWrapper component
	 * This is still needed for hosted iframe inputs
	 */
	private handleWrapperClick;
	/**
	 * Get the error code from the hosted input controller when the input is submitted or touched
	 *
	 * Can be used instead of the error returned by the `validate()` method since internally `primer-sdk-web`
	 * uses the same logic to compute the error code
	 *
	 * @returns {string|null}
	 */
	getError(): string | null;
	/**
	 * Common rendering logic for all card input components
	 */
	protected renderInput(): typeof nothing | import("lit-html").TemplateResult<1>;
}
/**
 * Card number input component with dynamic card network detection and selection
 */
declare class InputCardNumberComponent extends AbstractCardInputComponent {
	static styles: import("lit").CSSResult[];
	/**
	 * Configuration for this input component
	 */
	protected readonly config: InputComponentConfig;
	constructor();
	/**
	 * Handle network selection from the network selector component
	 */
	private handleNetworkSelected;
	/**
	 * Override the renderInput method to include the network selector
	 */
	protected renderInput(): typeof nothing | import("lit-html").TemplateResult<1>;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-card-number": InputCardNumberComponent;
	}
}
declare class InputCvvComponent extends AbstractCardInputComponent {
	static styles: import("lit").CSSResult[];
	protected readonly config: InputComponentConfig;
	constructor();
	render(): typeof import("lit-html").nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-cvv": InputCvvComponent;
	}
}
declare class InputCardExpiryComponent extends AbstractCardInputComponent {
	static styles: import("lit").CSSResult[];
	protected readonly config: InputComponentConfig;
	constructor();
	render(): typeof import("lit-html").nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-card-expiry": InputCardExpiryComponent;
	}
}
declare class InputCardHolderNameComponent extends AbstractCardInputComponent {
	static styles: import("lit").CSSResult[];
	protected readonly config: InputComponentConfig;
	constructor();
	private handleInput;
	render(): typeof import("lit-html").nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-input-card-holder-name": InputCardHolderNameComponent;
	}
}
/**
 * A form submit button component for card forms.
 * Provides a consistent submit button with translation support.
 */
declare class CardFormSubmitComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private readonly _userAssignedProps;
	private _internalButtonText;
	/**
	 * The button text to display.
	 * Falls back to localized default if not explicitly set.
	 */
	get buttonText(): string;
	set buttonText(value: string);
	headlessInstance: HeadlessUnitilsContextType;
	clientOptions: ClientOptionsContextType;
	sdkState: SdkStateContextType;
	cardFormContext: CardFormContext | null;
	/**
	 * The button variant to use.
	 * @default "primary"
	 */
	variant: string;
	/**
	 * Whether the button is disabled.
	 * @default false
	 */
	disabled: boolean;
	private handleClick;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-card-form-submit": CardFormSubmitComponent;
	}
}
/**
 * Component for displaying and selecting card networks
 * Uses context directly rather than properties
 *
 * @fires network-selected - Dispatched when a network is selected with the network name as detail
 */
declare class CardNetworkSelectorComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Card networks context from provider
	 */
	cardNetworks: CardNetworksContextType;
	headlessUtils: HeadlessUnitilsContextType;
	private selectedCardNetwork;
	/**
	 * Internal state to track if dropdown is open
	 */
	private isDropdownOpen;
	/**
	 * Index of the currently focused network in the dropdown
	 */
	private focusedNetworkIndex;
	/**
	 * Tracks if keyboard navigation is being used
	 */
	private isKeyboardNavigation;
	/**
	 * Reference to the dropdown button
	 */
	private buttonRef;
	/**
	 * Reference to the dropdown container
	 */
	private dropdownRef;
	/**
	 * Reference to network option elements
	 */
	private networkOptionRefs;
	/**
	 * Toggle the dropdown state
	 */
	private toggleDropdown;
	private getNetworkIconUrl;
	/**
	 * Get selectable networks from context
	 */
	private getSelectableNetworks;
	/**
	 * Get detected network from context
	 */
	private getDetectedNetwork;
	/**
	 * Get the index of the currently selected network
	 */
	private getSelectedNetworkIndex;
	/**
	 * Handle network selection
	 */
	private selectNetwork;
	/**
	 * Handle click outside to close dropdown
	 */
	private handleClickOutside;
	/**
	 * Handle mouse movement to disable keyboard navigation mode
	 */
	private handleMouseMove;
	/**
	 * Handle keydown events for keyboard navigation
	 */
	private handleKeyDown;
	/**
	 * Focus the current network option
	 */
	private focusNetworkOption;
	/**
	 * Save reference to network option element
	 */
	private setNetworkOptionRef;
	/**
	 * Attach event listener to the component for keydown events
	 * and to document for click outside and mousemove
	 */
	connectedCallback(): void;
	/**
	 * Handle document-level keydown events, but only when dropdown is open
	 * This allows keyboard navigation to continue working
	 */
	private handleDocumentKeyDown;
	/**
	 * Lifecycle: Remove all event listeners when disconnected
	 */
	disconnectedCallback(): void;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-card-network-selector": CardNetworkSelectorComponent;
	}
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-card-form": CardFormComponent;
	}
}
/**
 * Component for showing/hiding other payment methods when vault is present
 * Utilizes the collapsable component for smooth transitions
 */
declare class ShowOtherPaymentsComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Consume the vault manager context to interact with vault state
	 */
	vaultManager: VaultManagerContextType;
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-show-other-payments": ShowOtherPaymentsComponent;
	}
}
/**
 * Component for rendering native payment buttons (Apple Pay, Google Pay, PayPal)
 * with proper height calculations based on design system variables.
 */
declare class NativePaymentComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	paymentMethod: InitializedPaymentMethod | undefined;
	paymentManagers: InitializedManagersMap;
	computedStyles: CSSStyleDeclaration | null;
	disabled: boolean;
	private _buttonId;
	private loadManagerTask;
	private nativeButtonTask;
	constructor();
	attributeChangedCallback(name: string, oldValue: string | null, newValue: string | null): void;
	/**
	 * Calculates the button height based on CSS variables
	 * Mirrors the calculation used in the host styles
	 */
	private calculateButtonHeight;
	/**
	 * Creates render options with appropriate styles based on payment method type
	 */
	private createRenderOptions;
	protected updated(changedProperties: PropertyValues): void;
	/**
	 * Updates the disabled overlay based on the current disabled state
	 */
	private updateDisabledOverlay;
	private updateGooglePayOverlay;
	private updateRegularOverlay;
	render(): symbol | import("lit-html").TemplateResult<1> | undefined;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-native-payment": NativePaymentComponent;
	}
}
declare class PrimerCheckoutCompleteComponent extends LitElement {
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-checkout-complete": PrimerCheckoutCompleteComponent;
	}
}
declare class PrimerCheckoutErrorComponent extends LitElement {
	sdkState: SdkStateContextType;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-checkout-error": PrimerCheckoutErrorComponent;
	}
}
/**
 * A container component that connects to the SDK state context
 * and displays appropriate error messages based on error state.
 *
 * This component handles both process errors (typically from backend)
 * and validation errors (typically from client-side), managing when
 * and how they are displayed based on the current SDK state.
 */
declare class ErrorMessageContainerComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	/**
	 * Consume the SDK state context
	 * This automatically subscribes to changes in the SDK state
	 */
	protected sdkState?: SdkStateContextType;
	showProcessingErrors: boolean;
	/**
	 * Determine if an error should be shown
	 * Takes into account the current SDK state and component configuration
	 *
	 * @returns Boolean indicating whether an error should be shown
	 */
	private get shouldShowError();
	render(): typeof nothing | import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-error-message-container": ErrorMessageContainerComponent;
	}
}
declare class PrimerMainComponent extends LitElement {
	static styles: import("lit").CSSResult[];
	private hasAssignedContent;
	/**
	 * Inline slotchange event listener.
	 * Uses assignedNodes with flatten to detect if the slot has any nodes.
	 */
	private onSlotChange;
	paymentMethods: PaymentMethodsContextType;
	sdkState: SdkStateContextType;
	clientOptions: ClientOptionsContextType;
	render(): import("lit-html").TemplateResult<1>;
}
declare global {
	interface HTMLElementTagNameMap {
		"primer-main": PrimerMainComponent;
	}
}
/**
 * Main function to load the Primer SDK with all required dependencies and styles
 */
export declare function loadPrimer(): void;

export {
	AchPaymentComponent as AchPayment,
	ButtonComponent as Button,
	CardFormComponent as CardForm,
	CardFormSubmitComponent as CardFormSubmit,
	CardNetworkSelectorComponent as CardFormCardNetworkSelector,
	CollapsableComponent as Collapsable,
	DialogComponent as Dialog,
	DynamicPaymentComponent as DynamicPayment,
	ErrorMessageComponent as ErrorMessage,
	ErrorMessageContainerComponent as ErrorMessageContainer,
	InputCardExpiryComponent as CardFormExpiry,
	InputCardHolderNameComponent as CardFormName,
	InputCardNumberComponent as CardFormCardNumber,
	InputComponent as Input,
	InputCvvComponent as CardFormCVV,
	InputErrorComponent as CardFormError,
	InputLabelComponent as InputLabel,
	InputWrapperComponent as InputWrapper,
	NativePaymentComponent as NativePayment,
	PaymentMethodComponent as PaymentMethod,
	PortalComponent as Portal,
	PrimerCheckoutCompleteComponent as PrimerCheckoutComplete,
	PrimerCheckoutErrorComponent as PrimerCheckoutFailure,
	PrimerCheckoutStateComponent as PrimerCheckoutState,
	PrimerIconComponent as PrimerIcon,
	PrimerKlarnaComponent as PrimerKlarna,
	PrimerMainComponent as PrimerMain,
	RedirectPaymentComponent as RedirectPayment,
	ShowOtherPaymentsComponent as ShowOtherPayments,
	SpinnerComponent as Spinner,
	VaultCvvInputComponent as VaultCvvInput,
	VaultDeleteConfirmationComponent as VaultDeleteConfirmation,
	VaultEmptyStateComponent as VaultEmptyState,
	VaultErrorMessageComponent as VaultErrorMessage,
	VaultManagerComponent as VaultManager,
	VaultManagerHeaderComponent as VaultManagerHeader,
	VaultPaymentMethodItemComponent as VaultPaymentMethodItem,
	VaultPaymentSubmitComponent as VaultPaymentSubmit,
};

export {};
